/* WARNING: This file is generated!
 * Do not edit this file, but edit /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_zh_TW.xml instead and run
 * python configgen.py -wiz /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_zh_TW.xml to regenerate this file!
 */
#include "configdoc.h"
#include "docintf.h"

void addConfigDocs_zh_TW(DocIntf *doc)
{
  doc->setHeader(
              "此檔案描述了專案文件系統 Doxygen (www.doxygen.org) 所使用的設定。\n"
              "\n"
              "雙井字號(##)後面的所有文字都被視為注釋，並放置在 其前面的標籤之前。\n"
              "\n"
              "單井字號(#)後面的所有文字都被視為注釋，並將被忽略。 格式如下：\n"
              "TAG = value [value, ...]\n"
              "對于清單，也可以使用以下方式附加項目：\n"
              "TAG += value [value, ...]\n"
              "包含空格的值應放在引號(\" \")之間。\n"
              "\n"
              "注意：\n"
              "\n"
              "使用 Doxygen 將使用的組態檔與範本組態檔進行比較：\n"
              "doxygen -x [configFile]\n"
              "使用 Doxygen 將使用的組態檔與範本組態檔進行比較， 且不替換環境變數或 CMake 類型的替換變數：\n"
              "doxygen -x_noenv [configFile]"
             );
  doc->add(
              "DOXYFILE_ENCODING",
              "此標籤指定設定檔案中所有後續字元使用的編碼。預設值為 UTF-8，這也是此標籤首次出現之前所有文本使用的編碼。Doxygen 使用 libiconv （或\n"
              "libc 中內建的 iconv）進行轉碼。有關可能的編碼列資料表，請參閱 https://www.gnu.org/software/libiconv/。\n"
              "預設值為： UTF-8。"
          );
  doc->add(
              "PROJECT_NAME",
              "PROJECT_NAME 標籤是一個單詞（除非使用\n"
              "Doxywizard，否則為用雙引號括起來的一系列單詞），用於標識產生檔案的專案。此名稱用於大多數產生頁面的標题和其他一些地方。\n"
              "預設值為： My Project。"
          );
  doc->add(
              "PROJECT_NUMBER",
              "PROJECT_NUMBER 標籤可用於輸入專案或修订號。這對于歸檔產生的檔案或使用版本控制系統時很有用。"
          );
  doc->add(
              "PROJECT_BRIEF",
              "使用 PROJECT_BRIEF 標籤可以為專案提供可選的一行描述，該描述顯示在每個頁面的顶部，應該給查看者一個關于專案目的的快速概念。保持描述簡短。"
          );
  doc->add(
              "PROJECT_LOGO",
              "使用 PROJECT_LOGO 標籤可以指定包含在檔案中的徽標或圖示。徽標的最大高度不應超過 55 像素，最大寬度不應超過 200 像素。Doxygen\n"
              "會將徽標複製到輸出目錄。"
          );
  doc->add(
              "PROJECT_ICON",
              "使用 PROJECT_ICON 標籤可以指定顯示 HTML 檔案時包含在選項卡中的圖示。Doxygen 會將徽標複製到輸出目錄。"
          );
  doc->add(
              "OUTPUT_DIRECTORY",
              "OUTPUT_DIRECTORY 標籤用於指定產生檔案的（相對或絕對）路徑。如果輸入相對路徑，它將相對于 Doxygen\n"
              "啟動的位置。如果留空，則使用目前目錄。"
          );
  doc->add(
              "CREATE_SUBDIRS",
              "如果 CREATE_SUBDIRS 標籤設定為 YES ，Doxygen 將在每個輸出格式的輸出目錄下建立最多 4096 個子目錄（2\n"
              "個層級），並將產生的檔案分發送到這些目錄中。當向 Doxygen\n"
              "提供大量原始碼檔案時，啟用此選項很有用，否則將所有產生的檔案放在同一目錄中可能會導致檔案系統的效能問題。調整 CREATE_SUBDIRS_LEVEL\n"
              "以控制子目錄的數量。\n"
              "預設值為： NO。"
          );
  doc->add(
              "CREATE_SUBDIRS_LEVEL",
              "控制當 CREATE_SUBDIRS 標籤設定為 YES 時建立的子目錄數量。層級 0 資料表示 16 個目錄，每個層級增量使目錄數量加倍，在層級 8\n"
              "時結果為 4096 個目錄，這是預設值也是最大值。子目錄分為 2 個層級群組織，第一層始终有固定的 16 個目錄。\n"
              "最小值：0，最大值：8，預設值：8。\n"
              "此標籤要求標籤 CREATE_SUBDIRS 設定為YES。"
          );
  doc->add(
              "ALLOW_UNICODE_NAMES",
              "如果 ALLOW_UNICODE_NAMES 標籤設定為 YES ，Doxygen 將允許非 ASCII 字元出現在產生檔案的名稱中。如果設定為 NO ，非\n"
              "ASCII 字元將被轉義，例如 _xE3_x81_x84 將用於 Unicode U+3044。\n"
              "預設值為： NO。"
          );
  doc->add(
              "OUTPUT_LANGUAGE",
              "OUTPUT_LANGUAGE 標籤用於指定 Doxygen 產生的所有檔案使用的語言。Doxygen 將使用此資訊以正確的語言產生所有常量輸出。\n"
              "可能的值有：Afrikaans, Arabic, Armenian, Brazilian, Bulgarian, Catalan, Chinese,\n"
              "Chinese-Traditional, Croatian, Czech, Danish, Dutch, English （美國）, Esperanto,\n"
              "Farsi （波斯語）, Finnish, French, German, Greek, Hindi, Hungarian, Indonesian,\n"
              "Italian, Japanese, Japanese-en （日語帶英語訊息）, Korean, Korean-en （韓語帶英語訊息）,\n"
              "Latvian, Lithuanian, Macedonian, Norwegian, Persian （波斯語）, Polish, Portuguese,\n"
              "Romanian, Russian, Serbian, Serbian-Cyrillic, Slovak, Slovene, Spanish,\n"
              "Swedish, Turkish, Ukrainian和Vietnamese.\n"
              "預設值為： English。"
          );
  doc->add(
              "BRIEF_MEMBER_DESC",
              "如果 BRIEF_MEMBER_DESC 標籤設定為 YES ，Doxygen 將在檔案和類別檔案中包含簡要成員描述（類別似于 Javadoc ）。設定為\n"
              "NO 以停用此功能。\n"
              "預設值為： YES。"
          );
  doc->add(
              "REPEAT_BRIEF",
              "如果 REPEAT_BRIEF 標籤設定為 YES ，Doxygen 將在詳細描述之前添加成員或函式的簡要描述。\n"
              "\n"
              "注意：如果 HIDE_UNDOC_MEMBERS 和 BRIEF_MEMBER_DESC 都設定為 NO ，簡要描述將被完全抑制。\n"
              "預設值為： YES。"
          );
  doc->add(
              "ABBREVIATE_BRIEF",
              "此標籤實現了一個准智能簡要描述縮寫器，用於形成各种列資料表中的文本。此列資料表中的每個字元串，如果作為簡要描述的前導文本找到，將從文本中剥离，處理整個列資料\n"
              "表後的結果用作註解文本。否則，簡要描述按原樣使用。如果留空，則使用以下值（$name 自動取代為實體名稱）：The $name class, The\n"
              "$name widget, The $name file, is, provides, specifies, contains, represents,\n"
              "a, an和the."
          );
  doc->add(
              "ALWAYS_DETAILED_SEC",
              "如果 ALWAYS_DETAILED_SEC 和 REPEAT_BRIEF 標籤都設定為 YES ，那麼即使只有簡要描述，Doxygen 也會產生詳細部分。\n"
              "預設值為： NO。"
          );
  doc->add(
              "INLINE_INHERITED_MEMB",
              "如果 INLINE_INHERITED_MEMB 標籤設定為 YES ，Doxygen\n"
              "將在類別的檔案中顯示所有繼承的成員，就像這些成員是普通類別成員一樣。基類別的構造函式、析構函式和赋值運算子將不會顯示。\n"
              "預設值為： NO。"
          );
  doc->add(
              "FULL_PATH_NAMES",
              "如果 FULL_PATH_NAMES 標籤設定為 YES ，Doxygen 將在檔案列資料表和頭檔案中添加完整路徑前缀。如果設定為 NO\n"
              "，將使用使檔案名唯一的最短路徑。\n"
              "預設值為： YES。"
          );
  doc->add(
              "STRIP_FROM_PATH",
              "STRIP_FROM_PATH\n"
              "標籤可用於剥离使用者定義的部分路徑。只有當指定的字元串之一與路徑的左侧部分匹配時，才會進行剥离。該標籤可用於在檔案列資料表中顯示相對路徑。如果留空，則使用\n"
              "Doxygen 運行的目錄作為要剥离的路徑。\n"
              "\n"
              "請注意，您可以在此處指定絕對路徑，也可以指定相對路徑，這些路徑將相對于 Doxygen 啟動的目錄。\n"
              "此標籤要求標籤 FULL_PATH_NAMES 設定為YES。"
          );
  doc->add(
              "STRIP_FROM_INC_PATH",
              "STRIP_FROM_INC_PATH 標籤可用於剥离類別的檔案中提到的路徑的使用者定義部分，該路徑告诉读者應該包含哪個頭檔案才能使用類別。如果留空，則只\n"
              "使用包含類別定義的頭檔案的名稱。否則，應該指定通常使用 -I 標志傳遞給編译器的包含路徑列資料表。"
          );
  doc->add(
              "SHORT_NAMES",
              "如果 SHORT_NAMES 標籤設定為 YES ，Doxygen 將產生更短（但可讀性較差）的檔案名。如果您的檔案系統不支援長名稱（如 DOS、Mac 或\n"
              "CD-ROM），這可能很有用。\n"
              "預設值為： NO。"
          );
  doc->add(
              "JAVADOC_AUTOBRIEF",
              "如果 JAVADOC_AUTOBRIEF 標籤設定為 YES ，Doxygen 將把 Javadoc\n"
              "风格註解的第一行（直到第一個句點、問號或感叹號）解释為簡要描述。如果設定為 NO ，Javadoc 风格將資料表現得像普通的 Qt 风格註解（因此需要顯式的\n"
              "@brief 命令來獲得簡要描述。）\n"
              "預設值為： NO。"
          );
  doc->add(
              "JAVADOC_BANNER",
              "如果 JAVADOC_BANNER 標籤設定為 YES ，Doxygen 將把像\n"
              "/***************\n"
              "這樣的行解释為 Javadoc 风格註解\"横幅\"的開始。如果設定為 NO ，Javadoc 风格將資料表現得像普通註解，Doxygen 不會解释它。\n"
              "預設值為： NO。"
          );
  doc->add(
              "QT_AUTOBRIEF",
              "如果 QT_AUTOBRIEF 標籤設定為 YES ，Doxygen 將把 Qt 风格註解的第一行（直到第一個句點、問號或感叹號）解释為簡要描述。如果設定為\n"
              "NO ，Qt 风格將資料表現得像普通的 Qt 风格註解（因此需要顯式的 \\brief 命令來獲得簡要描述。）\n"
              "預設值為： NO。"
          );
  doc->add(
              "MULTILINE_CPP_IS_BRIEF",
              "MULTILINE_CPP_IS_BRIEF 標籤可以設定為 YES ，使 Doxygen 將多行 C++ 特殊註解塊（即 //! 或 ///\n"
              "註解塊）视為簡要描述。這曾经是預設行為。新的預設設定是將多行 C++ 註解塊视為詳細描述。如果您更喜欢旧的行為，請將此標籤設定為 YES 。\n"
              "\n"
              "請注意，將此標籤設定為 YES 也意味着不再識別 Rational Rose 註解。\n"
              "預設值為： NO。"
          );
  doc->add(
              "PYTHON_DOCSTRING",
              "預設情况下，Python 檔案字元串顯示為預格式化文本，不能使用 Doxygen 的特殊命令。通過將 PYTHON_DOCSTRING 設定為 NO\n"
              "，可以使用 Doxygen 的特殊命令，並且檔案字元串檔案塊的內容顯示為 Doxygen 檔案。\n"
              "預設值為： YES。"
          );
  doc->add(
              "INHERIT_DOCS",
              "如果 INHERIT_DOCS 標籤設定為 YES ，則未記錄的成員將繼承其重新實現的任何已記錄成員的檔案。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SEPARATE_MEMBER_PAGES",
              "如果 SEPARATE_MEMBER_PAGES 標籤設定為 YES ，Doxygen 將為每個成員產生一個新頁面。如果設定為 NO\n"
              "，成員的檔案將成為包含它的檔案/類別/命名空間的一部分。\n"
              "預設值為： NO。"
          );
  doc->add(
              "TAB_SIZE",
              "TAB_SIZE 標籤可用於設定制資料表符中的空格數。Doxygen 使用此值在程式碼片段中用空格取代制資料表符。\n"
              "最小值：1，最大值：16，預設值：4。"
          );
  doc->add(
              "ALIASES",
              "此標籤可用於指定多個在檔案中充當命令的別名。別名的形式為：\n"
              "name=value\n"
              "例如添加\n"
              "\"sideeffect=@par Side Effects:^^\"\n"
              "將允許您在檔案中放置命令 \\sideeffect （或 @sideeffect ），這將產生一個带有標题\"Side\n"
              "Effects:\"的使用者定義段落。請注意，您不能在別名的值部分放置 \\n 來插入換行符（在結果輸出中）。您可以在別名的值部分放置 ^^\n"
              "來插入換行符，就像原始檔案中有物理換行符一樣。當別名的值部分需要使用字面值 {、} 或 , 時，必須使用反斜線 (\\) 來轉義。這可能會與命令 \\{ 和\n"
              "\\} 衝突。建議使用版本 @{ 和 @} ，或使用雙重轉義 (\\\\{ 和 \\\\})"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_FOR_C",
              "如果您的專案僅包含 C 原始碼程式碼，請將 OPTIMIZE_OUTPUT_FOR_C 標籤設定為 YES 。Doxygen 随後將產生更适合 C\n"
              "的輸出。例如，將使用一些不同的名稱。將省略所有成員的列資料表等。\n"
              "預設值為： NO。"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_JAVA",
              "如果您的專案僅包含 Java 或 Python 原始碼程式碼，請將 OPTIMIZE_OUTPUT_JAVA 標籤設定為 YES 。Doxygen\n"
              "随後將產生更适合該語言的輸出。例如，命名空間將顯示為包，限定作用域將看起來不同等。\n"
              "預設值為： NO。"
          );
  doc->add(
              "OPTIMIZE_FOR_FORTRAN",
              "如果您的專案包含 Fortran 原始碼程式碼，請將 OPTIMIZE_FOR_FORTRAN 標籤設定為 YES 。Doxygen 随後將產生适合\n"
              "Fortran 的輸出。\n"
              "預設值為： NO。"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_VHDL",
              "如果您的專案包含 VHDL 原始碼程式碼，請將 OPTIMIZE_OUTPUT_VHDL 標籤設定為 YES 。Doxygen 随後將產生适合 VHDL\n"
              "的輸出。\n"
              "預設值為： NO。"
          );
  doc->add(
              "OPTIMIZE_OUTPUT_SLICE",
              "如果您的專案僅包含 Slice 原始碼程式碼，請將 OPTIMIZE_OUTPUT_SLICE 標籤設定為 YES 。Doxygen\n"
              "随後將產生更适合該語言的輸出。例如，命名空間將顯示為模組，類別型將分成更多群組等。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTENSION_MAPPING",
              "Doxygen 根據解析檔案的擴充功能名選择要使用的解析器。使用此標籤，您可以為給定擴充功能名設定要使用的解析器。Doxygen\n"
              "有內建映射，但您可以使用此標籤覆寫或擴充功能它。格式為 ext=language，其中 ext 是檔案擴充功能名，language 是 Doxygen\n"
              "支援的解析器之一：IDL、Java、JavaScript、Csharp (C#)、C、C++、Lex、D、PHP、md\n"
              "(Markdown)、Objective-C、Python、Slice、VHDL、Fortran（固定格式\n"
              "Fortran：FortranFixed，自由格式 Fortran：FortranFree，未知格式\n"
              "Fortran：Fortran。在後一种情况下，解析器尝試猜測程式碼是固定格式还是自由格式程式碼，這是 Fortran 類別型檔案的預設設定）。例如，要使\n"
              "Doxygen 將 .inc 檔案视為 Fortran 檔案（預設為 PHP），將 .f 檔案视為 C 檔案（預設為\n"
              "Fortran），請使用：inc=Fortran f=C。\n"
              "\n"
              "注意：對于沒有擴充功能名的檔案，您可以使用 no_extension 作為占位符。\n"
              "\n"
              "請注意，對于自定義擴充功能名，您还需要設定 FILE_PATTERNS，否則 Doxygen 不會讀取這些檔案。指定 no_extension 時，應將 *\n"
              "添加到 FILE_PATTERNS。\n"
              "\n"
              "注意，另請參閱 預設檔案擴充功能名映射列資料表。"
          );
  doc->add(
              "MARKDOWN_SUPPORT",
              "如果啟用了 MARKDOWN_SUPPORT 標籤，Doxygen 將根據 Markdown 格式前置處理所有註解，這允許更可读的檔案。有關詳細資訊，請參閱\n"
              "https://daringfireball.net/projects/markdown/。Markdown 處理的輸出進一步由 Doxygen\n"
              "處理，因此您可以將 Doxygen、HTML 和 XML 命令與 Markdown 格式混合使用。僅在向後兼容性問題時停用。\n"
              "預設值為： YES。"
          );
  doc->add(
              "MARKDOWN_STRICT",
              "如果啟用了 MARKDOWN_STRICT 標籤，Doxygen 將在 Doxygen 的本机標記格式與 Markdown\n"
              "衝突的情况下，也將註解中的文本视為 Markdown 格式。這僅在使用反引號的情况下相關。Doxygen\n"
              "的本机標記樣式允許單引號關閉以反引號開始的文本片段，然後將其视為引用文本片段，而在 Markdown\n"
              "中，此類別文本片段被视為逐字文本，僅在找到第二個匹配的反引號時才關閉。此外，Doxygen 的本机標記格式要求在反引號部分中出現雙引號時進行轉義，而\n"
              "Markdown 不需要這樣做。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 MARKDOWN_SUPPORT 設定為YES。"
          );
  doc->add(
              "TOC_INCLUDE_HEADINGS",
              "當 TOC_INCLUDE_HEADINGS 標籤設定為非零值時，直到該層級的所有標题都會自動包含在目錄中，即使它們沒有 id 屬性。\n"
              "注意： 此功能目前僅適用於 Markdown 標题。\n"
              "最小值：0，最大值：99，預設值：6。\n"
              "此標籤要求標籤 MARKDOWN_SUPPORT 設定為YES。"
          );
  doc->add(
              "MARKDOWN_ID_STYLE",
              "MARKDOWN_ID_STYLE 標籤可用於指定用於為 Markdown 標题產生標識符的演算法。注意：每個標識符都是唯一的。\n"
              "可能的值有：DOXYGEN 使用固定的'autotoc_md'字串後跟從0開始的序號和GITHUB\n"
              "使用標題的小寫版本，將任何空白替換為'-'並刪除標點符號.\n"
              "預設值為： DOXYGEN。\n"
              "此標籤要求標籤 MARKDOWN_SUPPORT 設定為YES。"
          );
  doc->add(
              "AUTOLINK_SUPPORT",
              "啟用後，Doxygen 尝試將對應于已記錄類別或命名空間的單詞連結到其相應的檔案。可以通過在單詞前放置 % 符號來防止個別情况下的此類別連結，或者通過將\n"
              "AUTOLINK_SUPPORT 設定為 NO 來全局防止。 AUTOLINK_IGNORE_WORDS 標籤中列出的單詞被排除在自動連結之外。\n"
              "預設值為： YES。"
          );
  doc->add(
              "AUTOLINK_IGNORE_WORDS",
              "此標籤指定一個單詞列資料表，當與檔案中單詞的開頭匹配時，如果通過 AUTOLINK_SUPPORT\n"
              "啟用了自動連結產生，將抑制自動連結產生。此列資料表不影响使用 # 或 \\link 或 \\ref 命令顯式建立的連結。\n"
              "此標籤要求標籤 AUTOLINK_SUPPORT 設定為YES。"
          );
  doc->add(
              "BUILTIN_STL_SUPPORT",
              "如果您使用 STL 類別（即 std::string、std::vector 等），但不想將 STL\n"
              "原始碼程式碼的（標籤檔案）作為輸入包含，則應將此標籤設定為 YES ，以便让 Doxygen 匹配參數包含 STL 類別的函式声明和定義（例如\n"
              "func(std::string); 與 func(std::string) {}）。這也使涉及 STL 類別的繼承和協作圖更加完整和准确。\n"
              "預設值為： NO。"
          );
  doc->add(
              "CPP_CLI_SUPPORT",
              "如果您使用 Microsoft 的 C++/CLI 語言，應將此選項設定為 YES 以啟用解析支援。\n"
              "預設值為： NO。"
          );
  doc->add(
              "SIP_SUPPORT",
              "如果您的專案僅包含 sip (see:\n"
              "https://www.riverbankcomputing.com/software) 原始碼程式碼，請將 SIP_SUPPORT 標籤設定為 YES\n"
              "。Doxygen 將像普通 C++ 一樣解析它們，但會假設所有類別在沒有顯式保護關键字時都使用公共繼承而不是私有繼承。\n"
              "預設值為： NO。"
          );
  doc->add(
              "IDL_PROPERTY_SUPPORT",
              "對于 Microsoft 的 IDL，有 propget 和 propput 屬性來指示屬性的 getter 和 setter 方法。將此選項設定為 YES\n"
              "將使 Doxygen 在檔案中用屬性取代 get 和 set\n"
              "方法。這僅在方法确實是取得或設定簡單類別型時才有效。如果不是這种情况，或者您想无论如何顯示方法，應將此選項設定為 NO 。\n"
              "預設值為： YES。"
          );
  doc->add(
              "DISTRIBUTE_GROUP_DOC",
              "如果在檔案中使用了成員分群組，並且 DISTRIBUTE_GROUP_DOC 標籤設定為 YES ，那麼 Doxygen\n"
              "將為群組中的其他成員重用群組中第一個成員的檔案（如果有）。預設情况下，群組的所有成員必须顯式記錄。\n"
              "預設值為： NO。"
          );
  doc->add(
              "GROUP_NESTED_COMPOUNDS",
              "如果將結構或類別添加到群組中並啟用了此選項，則任何嵌套的類別或結構也會添加到同一群組中。預設情况下，此選項被停用，必须通過 \\ingroup\n"
              "顯式添加嵌套複合類別型。\n"
              "預設值為： NO。"
          );
  doc->add(
              "SUBGROUPING",
              "將 SUBGROUPING 標籤設定為 YES\n"
              "以允許相同類別型的類別成員群組（例如一群組公共函式）作為該類別型的子群組放置（例如在公共函式部分下）。將其設定為 NO 以防止子群組化。或者，可以使用\n"
              "\\nosubgrouping 命令按類別執行此操作。\n"
              "預設值為： YES。"
          );
  doc->add(
              "INLINE_GROUPED_CLASSES",
              "當 INLINE_GROUPED_CLASSES 標籤設定為 YES 時，類別、結構和聯合體顯示在包含它們的群組中（例如使用\n"
              "\\ingroup），而不是在單独的頁面上（對于 HTML 和 Man 頁面）或部分中（對于 LaTeX 和 RTF）。\n"
              "\n"
              "請注意，此功能不能與 SEPARATE_MEMBER_PAGES 結合使用。\n"
              "預設值為： NO。"
          );
  doc->add(
              "INLINE_SIMPLE_STRUCTS",
              "當 INLINE_SIMPLE_STRUCTS 標籤設定為 YES 時，僅具有公共資料欄位或簡單 typedef\n"
              "欄位的結構、類別和聯合體將顯示在定義它們的作用域的檔案中（即檔案、命名空間或群組檔案），前提是此作用域已記錄。如果設定為 NO\n"
              "，結構、類別和聯合體將顯示在單独的頁面上（對于 HTML 和 Man 頁面）或部分中（對于 LaTeX 和 RTF）。\n"
              "預設值為： NO。"
          );
  doc->add(
              "TYPEDEF_HIDES_STRUCT",
              "啟用 TYPEDEF_HIDES_STRUCT 標籤後，結構、聯合體或列舉的 typedef 將記錄為具有 typedef 名稱的結構、聯合體或列舉。因此\n"
              "typedef struct TypeS {} TypeT 將在檔案中顯示為名為 TypeT 的結構。停用時，typedef\n"
              "將顯示為檔案、命名空間或類別的成員。結構將命名為 TypeS 。這通常對于 C 程式碼很有用，如果編碼约定要求所有複合類別型都是 typedef\n"
              "的，並且只引用 typedef，從不引用標籤名稱。\n"
              "預設值為： NO。"
          );
  doc->add(
              "LOOKUP_CACHE_SIZE",
              "可以使用 LOOKUP_CACHE_SIZE\n"
              "設定符號查找快取的大小。此快取用於根據符號的名稱和作用域解析符號。由於這可能是一個昂貴的過程，並且通常相同的符號在程式碼中出現多次，Doxygen\n"
              "會保留一個預解析符號的快取。如果快取太小，Doxygen\n"
              "會變慢。如果快取太大，會浪费記憶體。快取大小由以下公式給出：2^(16+LOOKUP_CACHE_SIZE)。有效範圍為 0..9，預設值為\n"
              "0，對應于快取大小 2^16=65536 個符號。在運行結束時，Doxygen 將報告快取使用情况並從速度角度建议最佳快取大小。\n"
              "最小值：0，最大值：9，預設值：0。"
          );
  doc->add(
              "NUM_PROC_THREADS",
              "NUM_PROC_THREADS 指定 Doxygen 在處理期間允許使用的執行緒數。設定為 0 時，Doxygen\n"
              "將根據系統中可用的核心數進行設定。您可以將其顯式設定為大于 0 的值，以更好地控制 CPU\n"
              "負載和處理速度之間的平衡。目前只有輸入處理可以使用多執行緒完成。由於這仍然是一個實驗性功能，預設值設定為\n"
              "1，這實際上停用了平行處理。請報告您遇到的任何問題。平行產生 dot 圖由 DOT_NUM_THREADS 設定控制。\n"
              "最小值：0，最大值：512，預設值：1。"
          );
  doc->add(
              "TIMESTAMP",
              "如果 TIMESTAMP 標籤設定為不同于 NO 的值，則每個產生的頁面將包含頁面產生時的日期或日期和時間。將此設定為 NO 有助于比較多次運行的輸出。\n"
              "可能的值有：YES, NO, DATETIME和DATE.\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTRACT_ALL",
              "如果 EXTRACT_ALL 標籤設定為 YES ，Doxygen\n"
              "將假設檔案中的所有實體都已記錄，即使沒有可用的檔案。私有類別成員和靜態檔案成員將被隐藏，除非分別設定了 EXTRACT_PRIVATE 或\n"
              "EXTRACT_STATIC 標籤為 YES 。\n"
              "注意： 這也將停用通常在 WARNINGS 設定為 YES 時產生的有關未記錄成員的警告。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTRACT_PRIVATE",
              "如果 EXTRACT_PRIVATE 標籤設定為 YES ，類別的所有私有成員將包含在檔案中。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTRACT_PRIV_VIRTUAL",
              "如果 EXTRACT_PRIV_VIRTUAL 標籤設定為 YES ，類別的已記錄私有虛擬方法將包含在檔案中。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTRACT_PACKAGE",
              "如果 EXTRACT_PACKAGE 標籤設定為 YES ，所有具有包或內部作用域的成員將包含在檔案中。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTRACT_STATIC",
              "如果 EXTRACT_STATIC 標籤設定為 YES ，檔案的所有靜態成員將包含在檔案中。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTRACT_LOCAL_CLASSES",
              "如果 EXTRACT_LOCAL_CLASSES 標籤設定為 YES ，在原始碼檔案中本地定義的類別（和結構）將包含在檔案中。如果設定為 NO\n"
              "，則只包含在頭檔案中定義的類別。對 Java 原始碼程式碼沒有任何影响。\n"
              "預設值為： YES。"
          );
  doc->add(
              "EXTRACT_LOCAL_METHODS",
              "此標志僅對 Objective-C 程式碼有用。如果設定為 YES ，在實現部分定義但不在介面中的本地方法將包含在檔案中。如果設定為 NO\n"
              "，則只包含介面中的方法。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTRACT_ANON_NSPACES",
              "如果此標志設定為 YES ，匿名命名空間的成員將被提取並在檔案中顯示為名為 'anonymous_namespace{file}' 的命名空間，其中\n"
              "file 將取代為包含匿名命名空間的檔案的基本名稱。預設情况下，匿名命名空間是隐藏的。\n"
              "預設值為： NO。"
          );
  doc->add(
              "RESOLVE_UNNAMED_PARAMS",
              "如果此標志設定為 YES ，声明中未命名參數的名稱將由相應的定義确定。預設情况下，未命名參數在輸出中保持未命名。\n"
              "預設值為： YES。"
          );
  doc->add(
              "HIDE_UNDOC_MEMBERS",
              "如果 HIDE_UNDOC_MEMBERS 標籤設定為 YES ，Doxygen 將隐藏已記錄類別或檔案中的所有未記錄成員。如果設定為 NO\n"
              "，這些成員將包含在各种概述中，但不產生檔案部分。如果啟用了 EXTRACT_ALL，此選項无效。\n"
              "預設值為： NO。"
          );
  doc->add(
              "HIDE_UNDOC_CLASSES",
              "如果 HIDE_UNDOC_CLASSES 標籤設定為 YES ，Doxygen 將隐藏類別層次結構中通常可見的所有未記錄類別。如果設定為 NO\n"
              "，這些類別將包含在各种概述中。如果啟用，此選項还將隐藏未記錄的 C++ 概念。如果啟用了 EXTRACT_ALL，此選項无效。\n"
              "預設值為： NO。"
          );
  doc->add(
              "HIDE_UNDOC_NAMESPACES",
              "如果 HIDE_UNDOC_NAMESPACES 標籤設定為 YES ，Doxygen 將隐藏命名空間層次結構中通常可見的所有未記錄命名空間。如果設定為\n"
              "NO ，這些命名空間將包含在各种概述中。如果啟用了 EXTRACT_ALL，此選項无效。\n"
              "預設值為： YES。"
          );
  doc->add(
              "HIDE_FRIEND_COMPOUNDS",
              "如果 HIDE_FRIEND_COMPOUNDS 標籤設定為 YES ，Doxygen 將隐藏所有友元声明。如果設定為 NO ，這些声明將包含在檔案中。\n"
              "預設值為： NO。"
          );
  doc->add(
              "HIDE_IN_BODY_DOCS",
              "如果 HIDE_IN_BODY_DOCS 標籤設定為 YES ，Doxygen 將隐藏在函式體內找到的任何檔案塊。如果設定為 NO\n"
              "，這些塊將附加到函式的詳細檔案塊。\n"
              "預設值為： NO。"
          );
  doc->add(
              "INTERNAL_DOCS",
              "INTERNAL_DOCS 標籤确定是否包含在 \\internal 命令後键入的檔案。如果標籤設定為 NO ，則檔案將被排除。將其設定為 YES\n"
              "以包含內部檔案。\n"
              "預設值為： NO。"
          );
  doc->add(
              "CASE_SENSE_NAMES",
              "通過正確設定選項 CASE_SENSE_NAMES ，Doxygen\n"
              "將能够更好地匹配底層檔案系統的功能。如果檔案系統區分大小寫（即它支援同一目錄中名稱僅大小寫不同的檔案），則必须將選項設定為 YES\n"
              "以正確處理輸入中出現的此類別檔案。對于不區分大小寫的檔案系統，應將選項設定為 NO 以正確處理為僅大小寫不同的符號編寫的輸出檔案，例如對于兩個類別，一個名為\n"
              "CLASS ，另一個名為 Class ，並且还支援引用檔案而无需指定完全匹配的大小寫。在 Windows（包括 Cygwin）和 macOS\n"
              "上，使用者通常應將此選項設定為 NO ，而在 Linux 或其他 Unix 系統上，通常應將其設定為 YES 。\n"
              "可能的值有：SYSTEM, NO和YES.\n"
              "預設值為： SYSTEM。"
          );
  doc->add(
              "HIDE_SCOPE_NAMES",
              "如果 HIDE_SCOPE_NAMES 標籤設定為 NO ，Doxygen 將在檔案中顯示具有完整類別和命名空間作用域的成員。如果設定為 YES\n"
              "，作用域將被隐藏。\n"
              "預設值為： NO。"
          );
  doc->add(
              "HIDE_COMPOUND_REFERENCE",
              "如果 HIDE_COMPOUND_REFERENCE 標籤設定為 NO （預設），Doxygen 將在頁面標题後附加额外的文本，例如類別參考。如果設定為\n"
              "YES ，複合引用將被隐藏。\n"
              "預設值為： NO。"
          );
  doc->add(
              "SHOW_HEADERFILE",
              "如果 SHOW_HEADERFILE 標籤設定為 YES ，則類別的檔案將顯示需要包含哪個檔案才能使用該類別。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SHOW_INCLUDE_FILES",
              "如果 SHOW_INCLUDE_FILES 標籤設定為 YES ，Doxygen 將在檔案的檔案中放置該檔案包含的檔案列資料表。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SHOW_GROUPED_MEMB_INC",
              "如果 SHOW_GROUPED_MEMB_INC 標籤設定為 YES ，Doxygen\n"
              "將為每個分群組成員添加一個包含语句到檔案中，告诉读者需要包含哪個檔案才能使用該成員。\n"
              "預設值為： NO。"
          );
  doc->add(
              "FORCE_LOCAL_INCLUDES",
              "如果 FORCE_LOCAL_INCLUDES 標籤設定為 YES ，Doxygen 將在檔案中列出使用雙引號而不是尖括號的包含檔案。\n"
              "預設值為： NO。"
          );
  doc->add(
              "INLINE_INFO",
              "如果 INLINE_INFO 標籤設定為 YES ，則會在內嵌成員的檔案中插入 [inline] 標記。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SORT_MEMBER_DOCS",
              "如果 SORT_MEMBER_DOCS 標籤設定為 YES ，Doxygen 將按成員名稱字母顺序對檔案和類別成員的（詳細）檔案進行排序。如果設定為 NO\n"
              "，成員將按声明顺序出現。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SORT_BRIEF_DOCS",
              "如果 SORT_BRIEF_DOCS 標籤設定為 YES ，Doxygen 將按成員名稱字母顺序對檔案、命名空間和類別成員的簡要描述進行排序。如果設定為\n"
              "NO ，成員將按声明顺序出現。請注意，這也會影响類別列資料表中類別的顺序。\n"
              "預設值為： NO。"
          );
  doc->add(
              "SORT_MEMBERS_CTORS_1ST",
              "如果 SORT_MEMBERS_CTORS_1ST 標籤設定為 YES ，Doxygen\n"
              "將對類別成員的（簡要和詳細）檔案進行排序，使構造函式和析構函式首先列出。如果設定為 NO ，構造函式將按 SORT_BRIEF_DOCS 和\n"
              "SORT_MEMBER_DOCS 定義的各自顺序出現。\n"
              "注意： 如果 SORT_BRIEF_DOCS 設定為 NO ，則在排序簡要成員檔案時忽略此選項。\n"
              "注意： 如果 SORT_MEMBER_DOCS 設定為 NO ，則在排序詳細成員檔案時忽略此選項。\n"
              "預設值為： NO。"
          );
  doc->add(
              "SORT_GROUP_NAMES",
              "如果 SORT_GROUP_NAMES 標籤設定為 YES ，Doxygen 將按字母顺序對群組名稱的層次結構進行排序。如果設定為 NO\n"
              "，群組名稱將按其定義顺序出現。\n"
              "預設值為： NO。"
          );
  doc->add(
              "SORT_BY_SCOPE_NAME",
              "如果 SORT_BY_SCOPE_NAME 標籤設定為 YES ，類別列資料表將按完全限定名稱（包括命名空間）排序。如果設定為 NO\n"
              "，類別列資料表將僅按類別名排序，不包括命名空間部分。\n"
              "注意： 如果 HIDE_SCOPE_NAMES 設定為 YES ，此選項不太有用。\n"
              "注意： 此選項僅適用於類別列資料表，不適用於字母列資料表。\n"
              "預設值為： NO。"
          );
  doc->add(
              "STRICT_PROTO_MATCHING",
              "如果啟用了 STRICT_PROTO_MATCHING 選項，並且 Doxygen\n"
              "無法正確解析函式的所有參數類別型，它將拒絕成員函式的原型和實現之間的匹配，即使只有一個候選者或者通過簡單的字元串匹配很明顯應該選择哪個候選者。通過停用\n"
              "STRICT_PROTO_MATCHING ，Doxygen 仍將在這种情况下接受原型和實現之間的匹配。\n"
              "預設值為： NO。"
          );
  doc->add(
              "GENERATE_TODOLIST",
              "GENERATE_TODOLIST 標籤可用於啟用（ YES ）或停用（ NO ）待办事項列資料表。此列資料表是通過在檔案中放置 \\todo 命令建立的。\n"
              "預設值為： YES。"
          );
  doc->add(
              "GENERATE_TESTLIST",
              "GENERATE_TESTLIST 標籤可用於啟用（ YES ）或停用（ NO ）測試列資料表。此列資料表是通過在檔案中放置 \\test 命令建立的。\n"
              "預設值為： YES。"
          );
  doc->add(
              "GENERATE_BUGLIST",
              "GENERATE_BUGLIST 標籤可用於啟用（ YES ）或停用（ NO ）錯誤列資料表。此列資料表是通過在檔案中放置 \\bug 命令建立的。\n"
              "預設值為： YES。"
          );
  doc->add(
              "GENERATE_DEPRECATEDLIST",
              "GENERATE_DEPRECATEDLIST 標籤可用於啟用（ YES ）或停用（ NO ）弃用列資料表。此列資料表是通過在檔案中放置\n"
              "\\deprecated 命令建立的。\n"
              "預設值為： YES。"
          );
  doc->add(
              "GENERATE_REQUIREMENTS",
              "GENERATE_REQUIREMENTS 標籤可用於啟用（ YES ）或停用（ NO ）需求頁面。啟用後，當輸入中至少出現一個带有\n"
              "\\requirement 命令的註解塊時，此頁面會自動建立。\n"
              "預設值為： YES。"
          );
  doc->add(
              "REQ_TRACEABILITY_INFO",
              "REQ_TRACEABILITY_INFO 標籤控制是否在需求頁面上顯示可追溯性資訊（僅在使用 \\requirement 註解塊時相關）。設定 NO\n"
              "將完全停用可追溯性資訊。設定 UNSATISFIED_ONLY 將顯示缺少满足關系（通過命令：\\satisfies）的需求列資料表。類別似地，設定\n"
              "UNVERIFIED_ONLY 將顯示缺少驗證關系（通過命令：\\verifies）的需求列資料表。將標籤設定為 YES（預設）將在適用時顯示兩個列資料表。\n"
              "可能的值有：YES, NO, UNSATISFIED_ONLY和UNVERIFIED_ONLY.\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_REQUIREMENTS 設定為YES。"
          );
  doc->add(
              "ENABLED_SECTIONS",
              "ENABLED_SECTIONS 標籤可用於啟用条件檔案部分，由 \\if <section_label> ... \\endif 和 \\cond\n"
              "<section_label> ... \\endcond 塊標記。"
          );
  doc->add(
              "MAX_INITIALIZER_LINES",
              "MAX_INITIALIZER_LINES\n"
              "標籤确定變數或巨集/定義的初始值可以顯示的最大行數，以便它出現在檔案中。如果初始化器包含的行數超過此處指定的數量，它將被隐藏。使用值 0\n"
              "可完全隐藏初始化器。无论此設定如何，都可以在檔案中使用 \\showinitializer 或 \\hideinitializer\n"
              "命令控制單個變數和巨集/定義的值的外观。\n"
              "最小值：0，最大值：10000，預設值：30。"
          );
  doc->add(
              "SHOW_USED_FILES",
              "將 SHOW_USED_FILES 標籤設定為 NO 以停用類別和結構檔案底部產生的檔案列資料表。如果設定為 YES ，列資料表將提及用於產生檔案的檔案。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SHOW_FILES",
              "將 SHOW_FILES 標籤設定為 NO 以停用檔案頁面的產生。這將從快速索引和檔案夹樹视圖（如果指定）中刪除檔案条目。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SHOW_NAMESPACES",
              "將 SHOW_NAMESPACES 標籤設定為 NO 以停用命名空間頁面的產生。這將從快速索引和檔案夹樹视圖（如果指定）中刪除命名空間条目。\n"
              "預設值為： YES。"
          );
  doc->add(
              "FILE_VERSION_FILTER",
              "FILE_VERSION_FILTER 標籤可用於指定 Doxygen\n"
              "應呼叫的程式或脚本，以取得每個檔案的目前版本（通常來自版本控制系統）。Doxygen 將通過執行（通過 popen()）命令 command\n"
              "input_file 來呼叫程式，其中 command 是 FILE_VERSION_FILTER 標籤的值， input_file 是 Doxygen\n"
              "提供的輸入檔案的名稱。程式寫入標准輸出的任何內容都用作檔案版本。例如，請參閱文件。"
          );
  doc->add(
              "LAYOUT_FILE",
              "LAYOUT_FILE 標籤可用於指定 Doxygen 將解析的布局檔案。布局檔案以獨立于輸出格式的方式控制產生輸出檔案的全局結構。要建立資料表示\n"
              "Doxygen 預設值的布局檔案，請使用 -l 選項運行 Doxygen。您可以選择在選項後指定檔案名，如果省略，則使用 DoxygenLayout.xml\n"
              "作為布局檔案的名稱。另請參閱第 \"Changing the layout of pages\" 節以取得資訊。\n"
              "\n"
              "請注意，如果您從包含名為 DoxygenLayout.xml 的檔案的目錄運行 Doxygen，即使 LAYOUT_FILE 標籤為空，Doxygen\n"
              "也會自動解析它。"
          );
  doc->add(
              "CITE_BIB_FILES",
              "CITE_BIB_FILES 標籤可用於指定一個或多個包含參考定義的 bib 檔案。這必须是 .bib 檔案列資料表。如果省略，會自動附加 .bib\n"
              "擴充功能名。這需要安裝 bibtex 工具。另請參閱 https://en.wikipedia.org/wiki/BibTeX 以取得更多資訊。對于\n"
              "LaTeX，可以使用 LATEX_BIB_STYLE 控制參考文献的樣式。要使用此功能，您需要在搜尋路徑中有 bibtex 和 perl 可用。另請參閱\n"
              "\\cite 以取得有關如何建立引用的資訊。"
          );
  doc->add(
              "EXTERNAL_TOOL_PATH",
              "EXTERNAL_TOOL_PATH 標籤可用於擴充功能搜尋路徑（PATH 环境變數），以便可以找到 latex 和 gs 等外部工具。\n"
              "注意： 使用 EXTERNAL_TOOL_PATH 指定的目錄添加到 PATH 變數已指定的路徑前面，並按指定的顺序添加。\n"
              "注意： 此選項對于 macOS 版本 14 (Sonoma) 及更高版本特別有用，當從 Doxywizard 運行 Doxygen\n"
              "時，因為在這种情况下，PATH 的任何使用者定義更改都會被忽略。macOS 上的一個典型示例是設定\n"
              "EXTERNAL_TOOL_PATH = /Library/TeX/texbin /usr/local/bin\n"
              "與標准路徑一起，Doxygen 在啟動外部工具時使用的完整搜尋路徑將變為\n"
              "PATH=/Library/TeX/texbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
          );
  doc->add(
              "QUIET",
              "QUIET 標籤可用於開啟/關閉 Doxygen 產生到標准輸出的訊息。如果 QUIET 設定為 YES ，這意味着訊息已關閉。\n"
              "預設值為： NO。"
          );
  doc->add(
              "WARNINGS",
              "WARNINGS 標籤可用於開啟/關閉 Doxygen 產生到標准錯誤（ stderr ）的警告訊息。如果 WARNINGS 設定為 YES\n"
              "，這意味着警告已開啟。\n"
              "\n"
              "提示：在編寫檔案時開啟警告。\n"
              "預設值為： YES。"
          );
  doc->add(
              "WARN_IF_UNDOCUMENTED",
              "如果 WARN_IF_UNDOCUMENTED 標籤設定為 YES ，Doxygen 將為未記錄的成員產生警告。如果 EXTRACT_ALL 設定為 YES\n"
              "，則此標志將自動停用。\n"
              "預設值為： YES。"
          );
  doc->add(
              "WARN_IF_DOC_ERROR",
              "如果 WARN_IF_DOC_ERROR 標籤設定為 YES ，Doxygen\n"
              "將為檔案中的潜在錯誤產生警告，例如在已記錄的函式中兩次記錄某些參數，或記錄不存在的參數或錯誤使用標記命令。\n"
              "預設值為： YES。"
          );
  doc->add(
              "WARN_IF_INCOMPLETE_DOC",
              "如果 WARN_IF_INCOMPLETE_DOC 設定為 YES ，Doxygen 將警告不完整的函式參數檔案。如果設定為 NO ，Doxygen\n"
              "將接受某些參數沒有檔案而不發出警告。\n"
              "預設值為： YES。"
          );
  doc->add(
              "WARN_NO_PARAMDOC",
              "可以啟用此 WARN_NO_PARAMDOC 選項以取得已記錄但沒有參數或傳回值檔案的函式的警告。如果設定為 NO ，Doxygen\n"
              "只會警告錯誤的參數檔案，而不會警告缺少檔案。如果 EXTRACT_ALL 設定為 YES ，則此標志將自動停用。另請參閱\n"
              "WARN_IF_INCOMPLETE_DOC\n"
              "預設值為： NO。"
          );
  doc->add(
              "WARN_IF_UNDOC_ENUM_VAL",
              "如果 WARN_IF_UNDOC_ENUM_VAL 選項設定為 YES ，Doxygen 將警告未記錄的列舉值。如果設定為 NO ，Doxygen\n"
              "將接受未記錄的列舉值。如果 EXTRACT_ALL 設定為 YES ，則此標志將自動停用。\n"
              "預設值為： NO。"
          );
  doc->add(
              "WARN_LAYOUT_FILE",
              "如果 WARN_LAYOUT_FILE 選項設定為 YES ，Doxygen 將警告在解析使用者定義的布局檔案時發現的問題，例如缺少或錯誤的元素。另請參閱\n"
              "LAYOUT_FILE 以取得詳細資訊。如果設定為 NO ，布局檔案的問題將被抑制。\n"
              "預設值為： YES。"
          );
  doc->add(
              "WARN_AS_ERROR",
              "如果 WARN_AS_ERROR 標籤設定為 YES ，則 Doxygen 將在遇到警告時立即停止。如果 WARN_AS_ERROR 標籤設定為\n"
              "FAIL_ON_WARNINGS ，則 Doxygen 將繼续運行，就像 WARN_AS_ERROR 標籤設定為 NO 一樣，但在 Doxygen\n"
              "過程結束時，Doxygen 將傳回非零狀態。如果 WARN_AS_ERROR 標籤設定為 FAIL_ON_WARNINGS_PRINT ，則 Doxygen\n"
              "的行為類別似于 FAIL_ON_WARNINGS ，但在未定義 WARN_LOGFILE 的情况下，Doxygen\n"
              "不會在其他訊息之間寫入警告訊息，而是在運行結束時寫入它們，如果定義了 WARN_LOGFILE，警告訊息除了在定義的檔案中外，还會在運行結束時顯示，除非\n"
              "WARN_LOGFILE 定義為 - 即標准輸出（stdout），在這种情况下，行為將保持為設定 FAIL_ON_WARNINGS。\n"
              "可能的值有：NO, YES, FAIL_ON_WARNINGS和FAIL_ON_WARNINGS_PRINT.\n"
              "預設值為： NO。"
          );
  doc->add(
              "WARN_FORMAT",
              "WARN_FORMAT 標籤确定 Doxygen 可以產生的警告訊息的格式。字元串應包含 $file、$line 和 $text\n"
              "標籤，它們將被警告起原始碼的檔案和行號以及警告文本取代。可選地，格式可以包含 $version，它將被檔案的版本取代（如果可以通過\n"
              "FILE_VERSION_FILTER 取得）\n"
              "另請參閱： WARN_LINE_FORMAT\n"
              "預設值為： $file:$line: $text。"
          );
  doc->add(
              "WARN_LINE_FORMAT",
              "在 WARN_FORMAT 命令的 $text 部分中，可能會給出對更具體位置的引用。為了更容易跳轉到此位置（在 Doxygen\n"
              "之外），使用者可以定義自定義的\"剪下\"/\"貼上\"字元串。示例：\n"
              "WARN_LINE_FORMAT = \"'vi $file +$line'\"\n"
              "另請參閱： WARN_FORMAT\n"
              "預設值為： at line $line of file $file。"
          );
  doc->add(
              "WARN_LOGFILE",
              "WARN_LOGFILE 標籤可用於指定應將警告和錯誤訊息寫入的檔案。如果留空，輸出將寫入標准錯誤（stderr）。如果無法開啟指定的檔案進行寫入，警告和\n"
              "錯誤訊息將寫入標准錯誤。當指定檔案 - 時，警告和錯誤訊息將寫入標准輸出（stdout）。"
          );
  doc->add(
              "INPUT",
              "INPUT 標籤用於指定包含已記錄原始碼檔案的檔案和/或目錄。您可以輸入檔案名如 myfile.cpp 或目錄如 /usr/src/myproject\n"
              "。用空格分隔檔案或目錄。另請參閱 FILE_PATTERNS 和 EXTENSION_MAPPING\n"
              "注意： 如果此標籤為空，則搜尋目前目錄。"
          );
  doc->add(
              "INPUT_ENCODING",
              "此標籤可用於指定 Doxygen 解析的原始碼檔案的字元編碼。Doxygen 內部使用 UTF-8 編碼。Doxygen 使用 libiconv（或\n"
              "libc 內建的 iconv）進行轉碼。請參閱 libiconv 檔案 (see:\n"
              "https://www.gnu.org/software/libiconv/)以取得可能的編碼列資料表。\n"
              "另請參閱： INPUT_FILE_ENCODING\n"
              "預設值為： UTF-8。"
          );
  doc->add(
              "INPUT_FILE_ENCODING",
              "此標籤可用於指定 Doxygen 解析的原始碼檔案的字元編碼。 INPUT_FILE_ENCODING\n"
              "標籤可用於基於每個檔案模式指定字元編碼。Doxygen 將檔案名與每個模式進行比較，如果有匹配，則應用編碼而不是預設的\n"
              "INPUT_ENCODING。字元編碼是以下形式的列資料表：pattern=encoding（如 *.php=ISO-8859-1）。\n"
              "另請參閱： INPUT_ENCODING 以取得有關支援編碼的更多資訊。"
          );
  doc->add(
              "FILE_PATTERNS",
              "如果 INPUT 標籤的值包含目錄，則可以使用 FILE_PATTERNS 標籤指定一個或多個通配符模式（如 *.cpp 和\n"
              "*.h）來過濾目錄中的原始碼檔案。\n"
              "\n"
              "請注意，對于自定義擴充功能名或未直接支援的擴充功能名，您还需要為擴充功能名設定 EXTENSION_MAPPING，否則 Doxygen 不會讀取這些檔案。\n"
              "\n"
              "請注意，預設選中的檔案模式列資料表可能與 預設檔案擴充功能名映射列資料表不同。\n"
              "\n"
              "如果留空，則測試以下模式：*.c, *.cc, *.cxx, *.cxxm, *.cpp, *.cppm, *.ccm, *.c++, *.c++m,\n"
              "*.java, *.ii, *.ixx, *.ipp, *.i++, *.inl, *.idl, *.ddl, *.odl, *.h, *.hh,\n"
              "*.hxx, *.hpp, *.h++, *.l, *.cs, *.d, *.php, *.php4, *.php5, *.phtml, *.inc,\n"
              "*.m, *.markdown, *.md, *.mm, *.dox (to be provided as Doxygen C comment),\n"
              "*.py, *.pyw, *.f90, *.f95, *.f03, *.f08, *.f18, *.f, *.for, *.vhd, *.vhdl,\n"
              "*.ucf, *.qsf和*.ice."
          );
  doc->add(
              "RECURSIVE",
              "RECURSIVE 標籤可用於指定是否也應搜尋輸入檔案的子目錄。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXCLUDE",
              "EXCLUDE 標籤可用於指定應從 INPUT 原始碼檔案中排除的檔案和/或目錄。這樣，您可以轻松地從根目錄使用 INPUT\n"
              "標籤指定的目錄樹中排除子目錄。\n"
              "\n"
              "請注意，相對路徑相對于運行 Doxygen 的目錄。"
          );
  doc->add(
              "EXCLUDE_SYMLINKS",
              "EXCLUDE_SYMLINKS 標籤可用於選择是否從輸入中排除作為符號連結（Unix 檔案系統功能）的檔案或目錄。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXCLUDE_PATTERNS",
              "如果 INPUT 標籤的值包含目錄，則可以使用 EXCLUDE_PATTERNS 標籤指定一個或多個通配符模式，以從這些目錄中排除某些檔案。\n"
              "\n"
              "請注意，通配符與具有絕對路徑的檔案匹配，因此要排除所有測試目錄，例如使用模式 */test/*"
          );
  doc->add(
              "EXCLUDE_SYMBOLS",
              "EXCLUDE_SYMBOLS\n"
              "標籤可用於指定一個或多個應從輸出中排除的符號名稱（命名空間、類別、函式等）。符號名稱可以是完全限定名稱、單詞，或者如果使用通配符\n"
              "*，則可以是子字元串。示例：ANamespace、AClass、ANamespace::AClass、ANamespace::*Test"
          );
  doc->add(
              "EXAMPLE_PATH",
              "EXAMPLE_PATH 標籤可用於指定一個或多個包含示例程式碼片段的檔案或目錄，這些程式碼片段被包含（請參閱 \\include 命令）。"
          );
  doc->add(
              "EXAMPLE_PATTERNS",
              "如果 EXAMPLE_PATH 標籤的值包含目錄，則可以使用 EXAMPLE_PATTERNS 標籤指定一個或多個通配符模式（如 *.cpp 和\n"
              "*.h）來過濾目錄中的原始碼檔案。如果留空，則包含所有檔案。"
          );
  doc->add(
              "EXAMPLE_RECURSIVE",
              "如果 EXAMPLE_RECURSIVE 標籤設定為 YES ，則无论 RECURSIVE 標籤的值如何，都將搜尋子目錄以查找與 \\include 或\n"
              "\\dontinclude 命令一起使用的輸入檔案。\n"
              "預設值為： NO。"
          );
  doc->add(
              "IMAGE_PATH",
              "IMAGE_PATH 標籤可用於指定一個或多個包含要包含在檔案中的影像的檔案或目錄（請參閱 \\image 命令）。"
          );
  doc->add(
              "INPUT_FILTER",
              "INPUT_FILTER 標籤可用於指定 Doxygen 應為每個輸入檔案呼叫的過濾器。Doxygen 將通過執行（通過\n"
              "popen()）命令來呼叫過濾器程式：\n"
              "\n"
              "<filter> <input-file>\n"
              "\n"
              "其中 <filter> 是 INPUT_FILTER 標籤的值，<input-file> 是輸入檔案的名稱。Doxygen\n"
              "随後將使用過濾器程式寫入標准輸出的輸出進行進一步處理。如果指定了 FILTER_PATTERNS，則忽略此標籤。\n"
              "\n"
              "請注意，過濾器不得添加或刪除行；它在掃描程式碼之前應用，但在產生輸出程式碼時不應用。如果添加或刪除行，锚點將無法正確放置。\n"
              "\n"
              "請注意，Doxygen 將使用處理並寫入標准輸出的資料進行進一步處理，因此不應將其他任何內容（如偵錯语句或使用的命令（因此在 Windows\n"
              "批處理檔案中始终使用 @echo OFF））寫入標准輸出。\n"
              "\n"
              "請注意，對于自定義擴充功能名或未直接支援的擴充功能名，您还需要為擴充功能名設定 EXTENSION_MAPPING，否則 Doxygen\n"
              "不會正確處理這些檔案。\n"
              ""
          );
  doc->add(
              "FILTER_PATTERNS",
              "FILTER_PATTERNS 標籤可用於基於每個檔案模式指定過濾器。Doxygen\n"
              "將檔案名與每個模式進行比較，如果有匹配，則應用過濾器。過濾器是以下形式的列資料表：pattern=filter（如\n"
              "*.cpp=my_cpp_filter）。請參閱 INPUT_FILTER 以取得有關如何使用過濾器的更多資訊。如果 FILTER_PATTERNS\n"
              "標籤為空或沒有模式匹配檔案名，則應用 INPUT_FILTER。\n"
              "\n"
              "請注意，對于自定義擴充功能名或未直接支援的擴充功能名，您还需要為擴充功能名設定 EXTENSION_MAPPING，否則 Doxygen\n"
              "不會正確處理這些檔案。\n"
              ""
          );
  doc->add(
              "FILTER_SOURCE_FILES",
              "如果 FILTER_SOURCE_FILES 標籤設定為 YES ，則輸入過濾器（如果使用 INPUT_FILTER\n"
              "設定）也將用於過濾用於產生要浏览的原始碼檔案的輸入檔案（即當 SOURCE_BROWSER 設定為 YES 時）。\n"
              "預設值為： NO。"
          );
  doc->add(
              "FILTER_SOURCE_PATTERNS",
              "FILTER_SOURCE_PATTERNS 標籤可用於基於每個檔案模式指定原始碼過濾器。模式將覆寫 FILTER_PATTERN\n"
              "的設定（如果有），也可以使用 *.ext= 停用特定模式的原始碼過濾器（因此不命名過濾器）。\n"
              "此標籤要求標籤 FILTER_SOURCE_FILES 設定為YES。"
          );
  doc->add(
              "USE_MDFILE_AS_MAINPAGE",
              "如果 USE_MDFILE_AS_MAINPAGE 標籤引用作為輸入一部分的 markdown\n"
              "檔案的名稱，則其內容將放置在主頁面上（index.html）。如果您的專案在例如 GitHub 上，並且想要將介绍頁面也重用於 Doxygen\n"
              "輸出，這可能很有用。"
          );
  doc->add(
              "IMPLICIT_DIR_DOCS",
              "如果 IMPLICIT_DIR_DOCS 標籤設定為 YES ，則在專案根目錄的子目錄中找到的任何 README.md 檔案都將用作該子目錄的檔案，除非\n"
              "README.md 以 \\dir、\\page 或 \\mainpage 命令開頭。如果設定為 NO ，則需要 README.md 檔案以顯式的 \\dir\n"
              "命令開頭才能用作目錄檔案。\n"
              "預設值為： YES。"
          );
  doc->add(
              "FORTRAN_COMMENT_AFTER",
              "Fortran 標准規定，對于固定格式的 Fortran 程式碼，從位置 72\n"
              "開始的所有字元都被视為註解。一個常見的擴充功能是允許在自動註解開始之前有更長的行。設定 FORTRAN_COMMENT_AFTER\n"
              "也將使在自動註解開始之前可以處理更長的行。\n"
              "最小值：7，最大值：10000，預設值：72。"
          );
  doc->add(
              "SOURCE_BROWSER",
              "如果 SOURCE_BROWSER 標籤設定為 YES ，則將產生原始碼檔案列資料表。已記錄的實體將與這些原始碼交叉引用。\n"
              "\n"
              "注意：要摆脱產生輸出中的所有原始碼程式碼，請确保也將 VERBATIM_HEADERS 設定為 NO 。\n"
              "預設值為： NO。"
          );
  doc->add(
              "INLINE_SOURCES",
              "將 INLINE_SOURCES 標籤設定為 YES 將直接在檔案中包含函式體、多行巨集、列舉或列資料表初始化變數。\n"
              "預設值為： NO。"
          );
  doc->add(
              "STRIP_CODE_COMMENTS",
              "將 STRIP_CODE_COMMENTS 標籤設定為 YES 將指示 Doxygen 從產生的原始碼程式碼片段中隐藏任何特殊註解塊。普通的 C、C++ 和\n"
              "Fortran 註解將始终可見。\n"
              "預設值為： YES。"
          );
  doc->add(
              "REFERENCED_BY_RELATION",
              "如果 REFERENCED_BY_RELATION 標籤設定為 YES ，則對于每個已記錄的實體，將列出引用它的所有已記錄函式。\n"
              "預設值為： NO。"
          );
  doc->add(
              "REFERENCES_RELATION",
              "如果 REFERENCES_RELATION 標籤設定為 YES ，則對于每個已記錄的函式，將列出該函式呼叫/使用的所有已記錄實體。\n"
              "預設值為： NO。"
          );
  doc->add(
              "REFERENCES_LINK_SOURCE",
              "如果 REFERENCES_LINK_SOURCE 標籤設定為 YES 且 SOURCE_BROWSER 標籤設定為 YES ，則\n"
              "REFERENCES_RELATION 和 REFERENCED_BY_RELATION\n"
              "列資料表中函式的超連結將連結到原始碼程式碼。否則，它們將連結到檔案。\n"
              "預設值為： YES。"
          );
  doc->add(
              "SOURCE_TOOLTIPS",
              "如果啟用了 SOURCE_TOOLTIPS\n"
              "（預設），則在原始碼程式碼中悬停超連結將顯示一個工具提示，其中包含其他資訊，如原型、簡要描述以及指向定義和檔案的連結。由於這會使 HTML\n"
              "檔案更大並使大檔案的加載速度稍慢，您可以選择停用此功能。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 SOURCE_BROWSER 設定為YES。"
          );
  doc->add(
              "USE_HTAGS",
              "如果 USE_HTAGS 標籤設定為 YES ，則對原始碼程式碼的引用將指向由 htags(1) 工具產生的 HTML，而不是 Doxygen\n"
              "內建的原始碼瀏覽器。 htags 工具是 GNU 全局原始碼標記系統的一部分（請參閱\n"
              "https://www.gnu.org/software/global/global.html）。您需要 4.8.6 或更高版本。\n"
              "\n"
              "要使用它，請執行以下操作：\n"
              "- 安裝最新版本的 global\n"
              "- 在設定檔案中啟用 SOURCE_BROWSER 和 USE_HTAGS\n"
              "- 确保 INPUT 指向原始碼程式碼樹的根目錄\n"
              "- 正常運行 doxygen\n"
              "\n"
              "Doxygen 將呼叫 htags （它將依次呼叫 gtags ），因此這些工具必须可從命令行獲得（即在搜尋路徑中）。\n"
              "\n"
              "結果：連結到原始碼程式碼的連結現在將指向 htags 的輸出，而不是 Doxygen 產生的原始碼瀏覽器。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 SOURCE_BROWSER 設定為YES。"
          );
  doc->add(
              "VERBATIM_HEADERS",
              "如果 VERBATIM_HEADERS 標籤設定為 YES ，Doxygen 將為每個指定包含的類別產生頭檔案的逐字副本。設定為 NO 以停用此功能。\n"
              "另請參閱： 第 \\class 節。\n"
              "預設值為： YES。"
          );
  doc->add(
              "CLANG_ASSISTED_PARSING",
              "如果 CLANG_ASSISTED_PARSING 標籤設定為 YES ，Doxygen 將使用 clang 解析器 (see:\n"
              "http://clang.llvm.org/)進行更准确的解析，但會降低效能。這對于範本丰富的 C++ 程式碼特別有用，因為 Doxygen\n"
              "的內建解析器缺少必要的類別型資訊。\n"
              "注意： 此選項的可用性取决于 Doxygen 是否使用 CMake 的 -Duse_libclang=ON 選項產生。\n"
              "預設值為： NO。"
          );
  doc->add(
              "CLANG_ADD_INC_PATHS",
              "如果 CLANG_ASSISTED_PARSING 標籤設定為 YES 且 CLANG_ADD_INC_PATHS 標籤設定為 YES ，Doxygen\n"
              "將把每個輸入的目錄添加到包含路徑。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 CLANG_ASSISTED_PARSING 設定為YES。"
          );
  doc->add(
              "CLANG_OPTIONS",
              "如果啟用了 clang 辅助解析，您可以向編译器提供在呼叫編译器時通常使用的命令行選項。請注意，Doxygen 已经為使用 INPUT 和\n"
              "INCLUDE_PATH 指定的檔案和目錄設定了包含路徑。\n"
              "此標籤要求標籤 CLANG_ASSISTED_PARSING 設定為YES。"
          );
  doc->add(
              "CLANG_DATABASE_PATH",
              "如果啟用了 clang 辅助解析，您可以為 clang 解析器提供包含名為 compile_commands.json 的檔案的目錄的路徑。此檔案是\n"
              "編译資料库 (see:\n"
              "http://clang.llvm.org/docs/HowToSetupToolingForLLVM.html)，包含構建原始碼檔案時使用的選項。這等效于\n"
              "向 clang 工具（如 clang-check）指定 -p 選項。然後這些選項將傳遞給解析器。使用 CLANG_OPTIONS 指定的任何選項也將被添加。\n"
              "注意： 此選項的可用性取决于 Doxygen 是否使用 CMake 的 -Duse_libclang=ON 選項產生。"
          );
  doc->add(
              "ALPHABETICAL_INDEX",
              "如果 ALPHABETICAL_INDEX 標籤設定為 YES ，將產生所有複合類別型的字母索引。如果專案包含大量類別、結構、聯合體或介面，請啟用此選項。\n"
              "預設值為： YES。"
          );
  doc->add(
              "IGNORE_PREFIX",
              "IGNORE_PREFIX 標籤可用於指定在產生索引標题時應忽略的前缀（或前缀列資料表）。 IGNORE_PREFIX\n"
              "標籤適用於類別、函式和成員名稱。實體將放置在移除前缀後實體名稱的首字母下的字母列資料表中。\n"
              "此標籤要求標籤 ALPHABETICAL_INDEX 設定為YES。"
          );
  doc->add(
              "GENERATE_HTML",
              "如果 GENERATE_HTML 標籤設定為 YES ，Doxygen 將產生 HTML 輸出\n"
              "預設值為： YES。"
          );
  doc->add(
              "HTML_OUTPUT",
              "HTML_OUTPUT 標籤用於指定 HTML 檔案的放置位置。如果輸入相對路徑，則 OUTPUT_DIRECTORY 的值將放在其前面。\n"
              "預設目錄為：html。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_FILE_EXTENSION",
              "HTML_FILE_EXTENSION 標籤可用於指定每個產生的 HTML 頁面的檔案擴充功能名（例如： .htm, .php, .asp）。\n"
              "預設值為： .html。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_HEADER",
              "HTML_HEADER 標籤可用於為每個產生的 HTML 頁面指定使用者定義的 HTML 頭檔案。如果標籤留空，Doxygen 將產生標准頭檔案。\n"
              "\n"
              "要獲得有效的 HTML，頭檔案需要包含 Doxygen 需要的任何脚本和樣式資料表，這取决于使用的設定選項（例如設定\n"
              "GENERATE_TREEVIEW）。强烈建议使用預設頭檔案開始：\n"
              "doxygen -w html new_header.html new_footer.html new_stylesheet.css\n"
              "YourConfigFile\n"
              "然後修改檔案 new_header.html 。另請參閱第 \"Doxygen usage\" 節以取得有關如何產生 Doxygen\n"
              "通常使用的預設頭檔案的資訊。\n"
              "注意： 頭檔案可能會更改，因此通常在升級到更新版本的 Doxygen 時必须重新產生預設頭檔案。有關可用標記和程式碼區塊名稱的說明，請參閱文件。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_FOOTER",
              "HTML_FOOTER 標籤可用於為每個產生的 HTML 頁面指定使用者定義的 HTML 頁脚。如果標籤留空，Doxygen 將產生標准頁脚。請參閱\n"
              "HTML_HEADER 以取得有關如何產生預設頁脚以及頁脚內可以使用哪些特殊命令的更多資訊。另請參閱第 \"Doxygen usage\" 節以取得有關如何產生\n"
              "Doxygen 通常使用的預設頁脚的資訊。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_STYLESHEET",
              "HTML_STYLESHEET 標籤可用於指定每個 HTML 頁面使用的使用者定義的層聯樣式資料表。它可用於微調 HTML\n"
              "輸出的外观。如果留空，Doxygen 將產生預設樣式資料表。另請參閱第 \"Doxygen usage\" 節以取得有關如何產生 Doxygen\n"
              "通常使用的樣式資料表的資訊。\n"
              "注意： 建议使用 HTML_EXTRA_STYLESHEET 而不是此標籤，因為它更健壮，並且此標籤（HTML_STYLESHEET）將來會過時。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_EXTRA_STYLESHEET",
              "HTML_EXTRA_STYLESHEET 標籤可用於指定在 Doxygen\n"
              "建立的標准樣式資料表之後包含的其他使用者定義的層聯樣式資料表。使用此選項可以覆寫某些樣式方面。這比使用 HTML_STYLESHEET\n"
              "更可取，因為它不會取代標准樣式資料表，因此對未來的更新更加健壮。Doxygen 會將樣式資料表檔案複製到輸出目錄。\n"
              "注意： 额外樣式資料表檔案的顺序很重要（例如，列資料表中的最後一個樣式資料表覆寫列資料表中前一個樣式資料表的設定）。\n"
              "注意： 由於目前無法在 Webkit/Chromium 中覆寫捲軸的樣式，如果指定了一個或多個额外樣式資料表，預設 doxygen.css\n"
              "中將省略捲軸樣式。因此，如果需要自定義捲軸，必须顯式添加。例如，請參閱文件。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_EXTRA_FILES",
              "HTML_EXTRA_FILES 標籤可用於指定一個或多個應複製到 HTML 輸出目錄的额外影像或其他原始碼檔案。請注意，這些檔案將被複製到基本 HTML\n"
              "輸出目錄。使用 HTML_HEADER 和/或 HTML_FOOTER 檔案中的 $relpath^ 標記來加載這些檔案。在 HTML_STYLESHEET\n"
              "檔案中，僅使用檔案名。另請注意，檔案將按原樣複製；沒有可用的命令或標記。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_COLORSTYLE",
              "HTML_COLORSTYLE 標籤可用於指定產生的 HTML 輸出是否應以深色或浅色主题呈現。\n"
              "可能的值有：LIGHT 始終產生淺色模式輸出, DARK 始終產生深色模式輸出, AUTO_LIGHT\n"
              "根據使用者偏好自動設定模式，如果未設定偏好則使用淺色模式（預設）, AUTO_DARK\n"
              "根據使用者偏好自動設定模式，如果未設定偏好則使用深色模式和TOGGLE 允許使用者透過按鈕在淺色和深色模式之間切換.\n"
              "預設值為： AUTO_LIGHT。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_COLORSTYLE_HUE",
              "HTML_COLORSTYLE_HUE 標籤控制 HTML 輸出的色彩。Doxygen\n"
              "將根據此色彩調整樣式資料表和背景影像中的色彩。色調指定為色环上的角度，請參閱 https://en.wikipedia.org/wiki/Hue\n"
              "以取得更多資訊。例如，值 0 資料表示红色，60 是黄色，120 是绿色，180 是青色，240 是蓝色，300 是紫色，360 又是红色。\n"
              "最小值：0，最大值：359，預設值：220。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_COLORSTYLE_SAT",
              "HTML_COLORSTYLE_SAT 標籤控制 HTML 輸出中色彩的纯度（或饱和度）。值為 0 時，輸出將僅使用灰度。值為 255\n"
              "將產生最鲜艳的色彩。\n"
              "最小值：0，最大值：255，預設值：100。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_COLORSTYLE_GAMMA",
              "HTML_COLORSTYLE_GAMMA 標籤控制應用於 HTML 輸出中色彩亮度分量的伽马校正。低于 100 的值逐渐使輸出變亮，而高于 100\n"
              "的值使輸出變暗。該值除以 100 是實際應用的伽马值，因此 80 資料表示伽马為 0.8，值 220 資料表示伽马為 2.2，100 不改變伽马。\n"
              "最小值：40，最大值：240，預設值：80。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_DYNAMIC_MENUS",
              "如果 HTML_DYNAMIC_MENUS 標籤設定為 YES ，則產生的 HTML 檔案將包含一個主索引，其中包含通過 JavaScript\n"
              "动態建立的垂直導航選單。如果停用，導航索引將由靜態嵌入每個 HTML 頁面的多層選項卡群組成。停用此選項以支援沒有 JavaScript 的瀏覽器，如 Qt\n"
              "說明瀏覽器。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_DYNAMIC_SECTIONS",
              "如果 HTML_DYNAMIC_SECTIONS 標籤設定為 YES ，則產生的 HTML 檔案將包含在頁面加載後可以隐藏和顯示的部分。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_CODE_FOLDING",
              "如果 HTML_CODE_FOLDING 標籤設定為 YES ，則類別和函式可以在產生的 HTML 原始碼程式碼中动態折叠和展開。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_COPY_CLIPBOARD",
              "如果 HTML_COPY_CLIPBOARD 標籤設定為 YES ，Doxygen\n"
              "將在程式碼和文本片段的右上角顯示一個圖示，允許使用者將其內容複製到剪贴板。請注意，這僅在瀏覽器支援且網頁通過安全性上下文 (see:\n"
              "https://www.w3.org/TR/secure-contexts/)提供服务時才有效，即使用 https: 或 file: 協定。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_PROJECT_COOKIE",
              "Doxygen 在瀏覽器中持久存儲一些設定（例如通過 cookie）。預設情况下，這些設定適用於 Doxygen 在所有專案中產生的所有 HTML 頁面。\n"
              "HTML_PROJECT_COOKIE 標籤可用於在專案特定的键下存儲設定，以便使用者首選項將單独存儲。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_INDEX_NUM_ENTRIES",
              "使用 HTML_INDEX_NUM_ENTRIES 可以控制最初在各种樹結構索引中顯示的首選条目數；使用者稍後可以动態展開和折叠条目。Doxygen\n"
              "將樹展開到最多可見指定數量条目的層級（除非完全折叠的樹已经超過此數量）。因此，將条目數設定為 1 將預設產生完全折叠的樹。0\n"
              "是一個特殊值，資料表示无限數量的条目，將導致預設產生完全展開的樹。\n"
              "最小值：0，最大值：9999，預設值：100。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "GENERATE_DOCSET",
              "如果 GENERATE_DOCSET 標籤設定為 YES ，將產生额外的索引檔案，可用作 OSX 10.5 (Leopard) 引入的 Apple 的\n"
              "Xcode 3 集成開發环境 (see:\n"
              "https://developer.apple.com/xcode/)的輸入。要建立檔案集，Doxygen 將在 HTML 輸出目錄中產生\n"
              "Makefile。運行 make 將在該目錄中產生 docset，運行 make install 將把 docset 安裝在\n"
              "~/Library/Developer/Shared/Documentation/DocSets 中，以便 Xcode 在啟動時找到它。請參閱 https:\n"
              "//developer.apple.com/library/archive/featuredarticles/DoxygenXcode/_index.htm\n"
              "l 以取得更多資訊。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "DOCSET_FEEDNAME",
              "此標籤确定 docset 订閱原始碼的名稱。檔案订閱原始碼提供了一個保護伞，可以將來自單個提供商（如公司或產品套件）的多個檔案集分群組。\n"
              "預設值為： Doxygen generated docs。\n"
              "此標籤要求標籤 GENERATE_DOCSET 設定為YES。"
          );
  doc->add(
              "DOCSET_FEEDURL",
              "此標籤确定 docset 订閱原始碼的 URL。檔案订閱原始碼提供了一個保護伞，可以將來自單個提供商（如公司或產品套件）的多個檔案集分群組。\n"
              "此標籤要求標籤 GENERATE_DOCSET 設定為YES。"
          );
  doc->add(
              "DOCSET_BUNDLE_ID",
              "此標籤指定一個應唯一標識檔案集包的字元串。這應該是反向域名樣式的字元串，例如 com.mycompany.MyDocSet。Doxygen 會將\n"
              ".docset 附加到名稱後。\n"
              "預設值為： org.doxygen.Project。\n"
              "此標籤要求標籤 GENERATE_DOCSET 設定為YES。"
          );
  doc->add(
              "DOCSET_PUBLISHER_ID",
              "DOCSET_PUBLISHER_ID 標籤指定一個應唯一標識檔案發行者的字元串。這應該是反向域名樣式的字元串，例如\n"
              "com.mycompany.MyDocSet.documentation。\n"
              "預設值為： org.doxygen.Publisher。\n"
              "此標籤要求標籤 GENERATE_DOCSET 設定為YES。"
          );
  doc->add(
              "DOCSET_PUBLISHER_NAME",
              "DOCSET_PUBLISHER_NAME 標籤標識檔案發行者。\n"
              "預設值為： Publisher。\n"
              "此標籤要求標籤 GENERATE_DOCSET 設定為YES。"
          );
  doc->add(
              "GENERATE_HTMLHELP",
              "如果 GENERATE_HTMLHELP 標籤設定為 YES ，Doxygen 會產生三個额外的 HTML 索引檔案： index.hhp 、\n"
              "index.hhc 和 index.hhk 。 index.hhp 是一個專案檔案，可以由 Windows 上的 Microsoft HTML Help\n"
              "Workshop 讀取。2021 年初，Microsoft 將原始頁面（包括下載連結）下線（HTML 說明工作室已经處于维護模式多年）。您可以從網路檔案下載\n"
              "HTML 說明工作室，网址為 安裝可執行檔案 (see:\n"
              "http://web.archive.org/web/20160201063255/https://download.microsoft.com/downl\n"
              "oad/0/A/9/0A939EF6-E31C-430F-A3DF-DFAE7960D564/htmlhelp.exe)。\n"
              "\n"
              "HTML Help Workshop 包含一個編译器，可以將 Doxygen 產生的所有 HTML 輸出轉換為單個編译的 HTML 檔案（\n"
              ".chm）。編译的 HTML 檔案現在用作 Windows 98 說明格式，將來將在所有 Windows 平台上取代旧的 Windows 說明格式（\n"
              ".hlp）。壓縮的 HTML 檔案还包含索引、目錄，您可以在檔案中搜尋單詞。HTML 工作室还包含一個用於壓縮 HTML 檔案的查看器。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "CHM_FILE",
              "CHM_FILE 標籤可用於指定產生的 .chm 檔案的檔案名。如果結果不應寫入 html 輸出目錄，可以在檔案前添加路徑。\n"
              "此標籤要求標籤 GENERATE_HTMLHELP 設定為YES。"
          );
  doc->add(
              "HHC_LOCATION",
              "HHC_LOCATION 標籤可用於指定 HTML 說明編译器（ hhc.exe ）的位置（包含檔案名的絕對路徑）。如果非空，Doxygen\n"
              "將尝試在產生的 index.hhp 上運行 HTML 說明編译器。\n"
              "檔案必須使用完整路徑指定。\n"
              "此標籤要求標籤 GENERATE_HTMLHELP 設定為YES。"
          );
  doc->add(
              "GENERATE_CHI",
              "GENERATE_CHI 標志控制是否產生單独的 .chi 索引檔案（ YES ）或將其包含在主 .chm 檔案中（ NO ）。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTMLHELP 設定為YES。"
          );
  doc->add(
              "CHM_INDEX_ENCODING",
              "CHM_INDEX_ENCODING 用於編碼 HtmlHelp 索引（ hhk ）、內容（ hhc ）和專案檔案內容。\n"
              "此標籤要求標籤 GENERATE_HTMLHELP 設定為YES。"
          );
  doc->add(
              "BINARY_TOC",
              "BINARY_TOC 標志控制 .chm 檔案中是產生二進制目錄（ YES ）还是普通目錄（ NO ）。此外，它啟用 Previous 和 Next\n"
              "按鈕。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTMLHELP 設定為YES。"
          );
  doc->add(
              "TOC_EXPAND",
              "TOC_EXPAND 標志可以設定為 YES ，以便為群組成員向 HTML 說明檔案的目錄和樹视圖添加额外專案。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTMLHELP 設定為YES。"
          );
  doc->add(
              "SITEMAP_URL",
              "SITEMAP_URL 標籤用於指定使用者在檔案部署期間將產生的檔案放置在伺服器上的位置的完整 URL。產生的站點地圖称為 sitemap.xml，放置在\n"
              "HTML_OUTPUT 指定的目錄中。如果未指定 SITEMAP_URL ，則不會產生站點地圖。有關站點地圖協定的資訊，請參閱\n"
              "https://www.sitemaps.org\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "GENERATE_QHP",
              "如果 GENERATE_QHP 標籤設定為 YES 且 QHP_NAMESPACE 和 QHP_VIRTUAL_FOLDER\n"
              "都已設定，將產生额外的索引檔案，可用作 Qt 的 qhelpgenerator 的輸入，以產生產生 HTML 檔案的 Qt 壓縮說明（ .qch）。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "QCH_FILE",
              "如果指定了 QHG_LOCATION 標籤， QCH_FILE 標籤可用於指定產生的 .qch 檔案的檔案名。指定的路徑相對于 HTML 輸出檔案夹。\n"
              "此標籤要求標籤 GENERATE_QHP 設定為YES。"
          );
  doc->add(
              "QHP_NAMESPACE",
              "QHP_NAMESPACE 標籤指定產生 Qt 說明專案輸出時使用的命名空間。有關更多資訊，請參閱 Qt 說明專案 / 命名空間 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#namespace)。\n"
              "預設值為： org.doxygen.Project。\n"
              "此標籤要求標籤 GENERATE_QHP 設定為YES。"
          );
  doc->add(
              "QHP_VIRTUAL_FOLDER",
              "QHP_VIRTUAL_FOLDER 標籤指定產生 Qt 說明專案輸出時使用的命名空間。有關更多資訊，請參閱 Qt 說明專案 / 虛擬檔案夹 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#virtual-folders)。\n"
              "預設值為： doc。\n"
              "此標籤要求標籤 GENERATE_QHP 設定為YES。"
          );
  doc->add(
              "QHP_CUST_FILTER_NAME",
              "如果設定了 QHP_CUST_FILTER_NAME 標籤，它指定要添加的自定義過濾器的名稱。有關更多資訊，請參閱 Qt 說明專案 / 自定義過濾器\n"
              "(see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters)。\n"
              "此標籤要求標籤 GENERATE_QHP 設定為YES。"
          );
  doc->add(
              "QHP_CUST_FILTER_ATTRS",
              "QHP_CUST_FILTER_ATTRS 標籤指定要添加的自定義過濾器的屬性列資料表。有關更多資訊，請參閱 Qt 說明專案 / 自定義過濾器 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters)。\n"
              "此標籤要求標籤 GENERATE_QHP 設定為YES。"
          );
  doc->add(
              "QHP_SECT_FILTER_ATTRS",
              "QHP_SECT_FILTER_ATTRS 標籤指定此專案的過濾器部分匹配的屬性列資料表。Qt 說明專案 / 過濾器屬性 (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#filter-attributes)。\n"
              "此標籤要求標籤 GENERATE_QHP 設定為YES。"
          );
  doc->add(
              "QHG_LOCATION",
              "QHG_LOCATION 標籤可用於指定 Qt 的 qhelpgenerator 的位置（包含檔案名的絕對路徑）。如果非空，Doxygen 將尝試在產生的\n"
              ".qhp 檔案上運行 qhelpgenerator。\n"
              "此標籤要求標籤 GENERATE_QHP 設定為YES。"
          );
  doc->add(
              "GENERATE_ECLIPSEHELP",
              "如果 GENERATE_ECLIPSEHELP 標籤設定為 YES ，將產生额外的索引檔案，與 HTML 檔案一起，它們形成一個 Eclipse\n"
              "說明外掛程式。要安裝此外掛程式並使其在 Eclipse 的說明內容選單下可用，需要將包含 HTML 和 XML 檔案的目錄的內容複製到 eclipse\n"
              "的外掛程式目錄中。外掛程式目錄中的目錄名稱應與 ECLIPSE_DOC_ID 值相同。複製後，Eclipse 需要重新啟動才能顯示說明。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "ECLIPSE_DOC_ID",
              "Eclipse 說明外掛程式的唯一標識符。安裝外掛程式時，包含 HTML 和 XML 檔案的目錄名稱也應具有此名稱。每個檔案集應具有自己的標識符。\n"
              "預設值為： org.doxygen.Project。\n"
              "此標籤要求標籤 GENERATE_ECLIPSEHELP 設定為YES。"
          );
  doc->add(
              "DISABLE_INDEX",
              "如果您想完全控制產生的 HTML 頁面的布局，可能需要停用索引並用您自己的索引取代它。 DISABLE_INDEX 標籤可用於開啟/關閉每個 HTML\n"
              "頁面顶部的壓縮索引（選項卡）。值為 NO 啟用索引，值 YES 停用它。由於索引中的選項卡包含與導航樹相同的資訊，如果您还將\n"
              "GENERATE_TREEVIEW 設定為 YES ，則可以將此選項設定為 YES 。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "GENERATE_TREEVIEW",
              "GENERATE_TREEVIEW 標籤用於指定是否應產生樹状索引結構以顯示層次資訊。如果標籤值設定為 YES\n"
              "，將產生一個包含樹状索引結構的侧面板（就像為 HTML 說明產生的結構一樣）。為此，需要一個支援 JavaScript、DHTML、CSS\n"
              "和框架的瀏覽器（即任何現代瀏覽器）。Windows 使用者可能最好使用 HTML 說明功能。通過自定義樣式資料表（請參閱\n"
              "HTML_EXTRA_STYLESHEET），可以進一步微調索引的外观（請參閱 \"Fine-tuning the output\" ）。例如，Doxygen\n"
              "產生的預設樣式資料表有一個示例，顯示如何在樹的根部放置影像而不是\n"
              "PROJECT_NAME。由於樹基本上比選項卡索引具有更多詳細資訊，您可以考虑在啟用此選項時將 DISABLE_INDEX 設定為 YES 。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "PAGE_OUTLINE_PANEL",
              "當 GENERATE_TREEVIEW 設定為 YES 時， PAGE_OUTLINE_PANEL\n"
              "選項确定是否在屏幕右侧顯示一個额外的導航面板，顯示主頁面的內容大纲，類別似于例如\n"
              "https://developer.android.com/reference。如果 GENERATE_TREEVIEW 設定為 NO ，此選項无效。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "FULL_SIDEBAR",
              "當 GENERATE_TREEVIEW 設定為 YES 時， FULL_SIDEBAR 選項确定侧邊緣栏是否僅限于樹视圖區域（值 NO\n"
              "）还是應該延伸到視窗的整個高度（值 YES ）。將此設定為 YES 會產生類別似于例如 https://docs.readthedocs.io\n"
              "的布局，內容空間更大，但專案徽標、標题和描述的空間更小。如果 GENERATE_TREEVIEW 設定為 NO ，此選項无效。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "ENUM_VALUES_PER_LINE",
              "ENUM_VALUES_PER_LINE 標籤可用於設定 Doxygen 在產生的 HTML 檔案中每行分群組的列舉值數量。\n"
              "\n"
              "請注意，值為 0 將完全抑制列舉值出現在概述部分中。\n"
              "最小值：0，最大值：20，預設值：4。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "SHOW_ENUM_VALUES",
              "當設定 SHOW_ENUM_VALUES 標籤時，Doxygen 將在列舉助記符旁邊緣顯示指定的列舉值。\n"
              "預設值為： NO。"
          );
  doc->add(
              "TREEVIEW_WIDTH",
              "如果啟用了樹视圖（請參閱 GENERATE_TREEVIEW），則此標籤可用於設定顯示樹的框架的初始寬度（以像素為單位）。\n"
              "最小值：0，最大值：1500，預設值：250。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "EXT_LINKS_IN_WINDOW",
              "如果 EXT_LINKS_IN_WINDOW 選項設定為 YES ，Doxygen 將在單独的視窗中開啟通過標籤檔案匯入的外部符號的連結。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "OBFUSCATE_EMAILS",
              "如果 OBFUSCATE_EMAILS 標籤設定為 YES ，Doxygen 將混淆电子郵件位址。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "HTML_FORMULA_FORMAT",
              "如果 HTML_FORMULA_FORMAT 選項設定為 svg ，Doxygen 將使用 pdf2svg 工具（請參閱\n"
              "https://github.com/dawbarton/pdf2svg）或 inkscape（請參閱 https://inkscape.org）為\n"
              "HTML 輸出產生 SVG 影像而不是 PNG。這些影像在縮放分辨率下通常看起來更好。\n"
              "可能的值有：png （預設）和svg （看起來更好，但需要pdf2svg或inkscape工具）.\n"
              "預設值為： png。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "FORMULA_FONTSIZE",
              "使用此標籤更改包含在 HTML 檔案中作為影像的 LaTeX 公式的字型大小。在成功運行 Doxygen 後更改字型大小時，您需要手动從 HTML\n"
              "輸出目錄中刪除任何 form_*.png 影像以强制重新產生它們。\n"
              "最小值：8，最大值：50，預設值：10。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "FORMULA_MACROFILE",
              "FORMULA_MACROFILE 可以包含 LaTeX \\newcommand 和 \\renewcommand 命令，以建立新的 LaTeX\n"
              "命令，用作公式中的構建塊。有關詳細資訊，請參閱第 \"Including formulas\" 節。"
          );
  doc->add(
              "USE_MATHJAX",
              "啟用 USE_MATHJAX 選項以使用 MathJax（請參閱 https://www.mathjax.org）呈現 LaTeX 公式，它使用客戶端\n"
              "JavaScript 進行呈現，而不是使用預呈現的位圖。如果您沒有安裝 LaTeX 或者您希望公式在 HTML\n"
              "輸出中看起來更漂亮，請使用此選項。啟用後，您可能还需要單独安裝 MathJax 並使用 MATHJAX_RELPATH 選項設定其路徑。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "MATHJAX_VERSION",
              "使用 MATHJAX_VERSION 可以指定要使用的 MathJax 版本。請注意，不同版本的 MathJax 對不同設定有不同的要求，因此在不同的\n"
              "MathJax 版本之間切換時，可能还需要更改其他 MathJax 設定。\n"
              "可能的值有：MathJax_2, MathJax_3和MathJax_4.\n"
              "預設值為： MathJax_2。\n"
              "此標籤要求標籤 USE_MATHJAX 設定為YES。"
          );
  doc->add(
              "MATHJAX_FORMAT",
              "啟用 MathJax 後，您可以設定 MathJax 輸出使用的預設輸出格式。有關輸出格式的更多詳細資訊，請參閱 MathJax 版本 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/output.html)、MathJax 版本 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/output/index.html) 和 MathJax 版本 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/output/index.htm)。\n"
              "可能的值有：HTML-CSS （較慢，但相容性最好。這是MathJax版本2的名稱，對於MathJax版本3將被轉換為 chtml ）, NativeMML\n"
              "（即MathML。僅MathJax 2支援。對於MathJax版本3將使用 chtml 代替。）, chtml\n"
              "（這是MathJax版本3的名稱，對於MathJax版本2將被轉換為HTML-CSS）和SVG.\n"
              "預設值為： HTML-CSS。\n"
              "此標籤要求標籤 USE_MATHJAX 設定為YES。"
          );
  doc->add(
              "MATHJAX_RELPATH",
              "當啟用 MathJax 時，您需要使用 MATHJAX_RELPATH 選項指定相對於 HTML 輸出目錄的位置。 對於 MathJax 版本\n"
              "2，目標目錄應包含 MathJax.js 腳本。例如，如果 mathjax 目錄 與 HTML 輸出目錄位於同一層級，則 MATHJAX_RELPATH\n"
              "應為 ../mathjax。 對於 MathJax 版本 3 和 4，目標目錄應包含 tex-<format>.js 腳本（其中 <format> 為\n"
              "chtml 或 svg）。預設值指向 MathJax 內容傳遞網路，以便您無需安裝 MathJax 即可快速查看結果。但是，強烈建議在部署前從\n"
              "https://www.mathjax.org 安裝 MathJax 的本地副本。 預設值為：\n"
              "- MathJax 版本 2 的情況: https://cdn.jsdelivr.net/npm/mathjax@2\n"
              "- MathJax 版本 3 的情況: https://cdn.jsdelivr.net/npm/mathjax@3\n"
              "- MathJax 版本 4 的情況: https://cdn.jsdelivr.net/npm/mathjax@4\n"
              "此標籤要求標籤 USE_MATHJAX 設定為YES。"
          );
  doc->add(
              "MATHJAX_EXTENSIONS",
              "MATHJAX_EXTENSIONS 標籤可用於指定在 MathJax 呈現期間應啟用的一個或多個 MathJax 擴充功能名稱。例如，對于\n"
              "MathJax 版本 2（請參閱 https://docs.mathjax.org/en/v2.7/tex.html）：\n"
              "MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols\n"
              "例如，對于 MathJax 版本 3（請參閱\n"
              "https://docs.mathjax.org/en/v3.2/input/tex/extensions/）：\n"
              "MATHJAX_EXTENSIONS = ams\n"
              "例如，對于 MathJax 版本 4（請參閱\n"
              "https://docs.mathjax.org/en/v4.0/input/tex/extensions/）：\n"
              "MATHJAX_EXTENSIONS = units\n"
              "請注意，對于 Mathjax 版本 4，已经自動加載了相當多的擴充功能。要在 Mathjax 版本 4 中停用包，可以使用前面带有减號的包名稱（- 如\n"
              "MATHJAX_EXTENSIONS += -textmacros）\n"
              "此標籤要求標籤 USE_MATHJAX 設定為YES。"
          );
  doc->add(
              "MATHJAX_CODEFILE",
              "MATHJAX_CODEFILE 標籤可用於指定一個包含 JavaScript 程式碼片段的檔案，這些程式碼將在 MathJax\n"
              "程式碼啟動時使用。有關更多詳細資訊，請參閱 Mathjax 網站：\n"
              "- MathJax 版本 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/)\n"
              "- MathJax 版本 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/)\n"
              "- MathJax 版本 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/)例如，請參閱文件。\n"
              "此標籤要求標籤 USE_MATHJAX 設定為YES。"
          );
  doc->add(
              "SEARCHENGINE",
              "當 SEARCHENGINE 標籤啟用時，Doxygen 將為 HTML 輸出產生一個搜尋框。底層搜尋引擎使用 JavaScript 和\n"
              "DHTML，應該可以在任何現代瀏覽器上運行。請注意，當使用 HTML 說明（GENERATE_HTMLHELP）、Qt\n"
              "說明（GENERATE_QHP）或檔案集（GENERATE_DOCSET）時，已经有搜尋功能，因此通常應停用此功能。對于大型專案，基於 JavaScript\n"
              "的搜尋引擎可能很慢，然後啟用 SERVER_BASED_SEARCH 可能提供更好的解决方案。可以使用键盘進行搜尋；要跳轉到搜尋框，請使用 <access\n"
              "key> + S（<access key> 取决于操作系統和瀏覽器，但通常是 <CTRL>、<ALT>/<option> 或兩者）。在搜尋框內，使用\n"
              "<cursor down key> 跳轉到搜尋結果視窗，可以使用 <cursor keys> 導航結果。按 <Enter> 選择專案或 <escape>\n"
              "取消搜尋。當光標在搜尋框內時，可以通過按 <Shift>+<cursor down> 選择過濾器選項。在這里也使用 <cursor keys>\n"
              "選择過濾器，使用 <Enter> 或 <escape> 激活或取消過濾器選項。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_HTML 設定為YES。"
          );
  doc->add(
              "SERVER_BASED_SEARCH",
              "當 SERVER_BASED_SEARCH 標籤啟用時，搜尋引擎將使用 Web 伺服器而不是使用 JavaScript 的 Web 客戶端來實現。根據\n"
              "EXTERNAL_SEARCH 設定，有兩种风格的基於 Web 伺服器的搜尋。停用時，Doxygen 將產生用於搜尋的 PHP\n"
              "脚本和脚本使用的索引檔案。當啟用 EXTERNAL_SEARCH 時，需要由外部工具提供索引和搜尋。有關詳細資訊，請參閱第 \"External\n"
              "Indexing and Searching\" 節。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 SEARCHENGINE 設定為YES。"
          );
  doc->add(
              "EXTERNAL_SEARCH",
              "當 EXTERNAL_SEARCH 標籤啟用時，Doxygen 將不再產生用於搜尋的 PHP 脚本。相反，搜尋結果將寫入 XML\n"
              "檔案，需要由外部索引器處理。Doxygen 將呼叫 SEARCHENGINE_URL 選項指向的外部搜尋引擎以取得搜尋結果。\n"
              "\n"
              "Doxygen 附带一個示例索引器（ doxyindexer ）和搜尋引擎（doxysearch.cgi），它們基於開原始碼搜尋引擎库 Xapian\n"
              "(see:\n"
              "https://xapian.org/)。\n"
              "\n"
              "有關詳細資訊，請參閱第 \"External Indexing and Searching\" 節。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 SEARCHENGINE 設定為YES。"
          );
  doc->add(
              "SEARCHENGINE_URL",
              "SEARCHENGINE_URL 應指向由 Web 伺服器托管的搜尋引擎，當啟用 EXTERNAL_SEARCH 時將傳回搜尋結果。\n"
              "\n"
              "Doxygen 附带一個示例索引器（ doxyindexer ）和搜尋引擎（doxysearch.cgi），它們基於開原始碼搜尋引擎库 Xapian\n"
              "(see:\n"
              "https://xapian.org/)。有關詳細資訊，請參閱第 \"External Indexing and Searching\" 節。\n"
              "此標籤要求標籤 SEARCHENGINE 設定為YES。"
          );
  doc->add(
              "SEARCHDATA_FILE",
              "當 SERVER_BASED_SEARCH 和 EXTERNAL_SEARCH 都啟用時，未索引的搜尋資料將寫入檔案以供外部工具索引。使用\n"
              "SEARCHDATA_FILE 標籤可以指定此檔案的名稱。\n"
              "預設檔案為：searchdata.xml。\n"
              "此標籤要求標籤 SEARCHENGINE 設定為YES。"
          );
  doc->add(
              "EXTERNAL_SEARCH_ID",
              "當 SERVER_BASED_SEARCH 和 EXTERNAL_SEARCH 都啟用時， EXTERNAL_SEARCH_ID\n"
              "標籤可用作專案的標識符。這與 EXTRA_SEARCH_MAPPINGS 結合使用很有用，可以搜尋多個專案並將結果重定向回正確的專案。\n"
              "此標籤要求標籤 SEARCHENGINE 設定為YES。"
          );
  doc->add(
              "EXTRA_SEARCH_MAPPINGS",
              "EXTRA_SEARCH_MAPPINGS 標籤可用於啟用搜尋除此設定檔案定義的專案以外的 Doxygen\n"
              "專案，但這些專案都添加到同一外部搜尋索引中。每個專案需要通過 EXTERNAL_SEARCH_ID 設定唯一的 id。然後搜尋映射將 id\n"
              "映射到可以找到檔案的相對位置。格式為：\n"
              "EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...\n"
              "此標籤要求標籤 SEARCHENGINE 設定為YES。"
          );
  doc->add(
              "GENERATE_LATEX",
              "如果 GENERATE_LATEX 標籤設定為 YES ，Doxygen 將產生 LaTeX 輸出。\n"
              "預設值為： YES。"
          );
  doc->add(
              "LATEX_OUTPUT",
              "LATEX_OUTPUT 標籤用於指定 LaTeX 檔案的放置位置。如果輸入相對路徑，則 OUTPUT_DIRECTORY 的值將放在其前面。\n"
              "預設目錄為：latex。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_CMD_NAME",
              "LATEX_CMD_NAME 標籤可用於指定要呼叫的 LaTeX 命令名稱。\n"
              "\n"
              "請注意，當不啟用 USE_PDFLATEX 時，預設值為 latex ；當啟用 USE_PDFLATEX 時，預設值為 pdflatex\n"
              "；在後一种情况下，如果選择 latex ，則會被 pdflatex 覆寫。對于特定的輸出語言，預設值可能已設定為不同的值，這取决于輸出語言的實現。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "MAKEINDEX_CMD_NAME",
              "MAKEINDEX_CMD_NAME 標籤可用於指定為 LaTeX 產生索引的命令名稱。\n"
              "注意： 此標籤在 Makefile / make.bat 中使用。\n"
              "另請參閱： LATEX_MAKEINDEX_CMD 用於產生輸出檔案（ .tex）中的部分。\n"
              "預設檔案為：makeindex。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_MAKEINDEX_CMD",
              "LATEX_MAKEINDEX_CMD 標籤可用於指定為 LaTeX 產生索引的命令名稱。如果第一個字元沒有反斜杠（ \\ ），則會自動添加到 LaTeX\n"
              "程式碼中。\n"
              "注意： 此標籤在產生輸出檔案（ .tex）中使用。\n"
              "另請參閱： MAKEINDEX_CMD_NAME 用於 Makefile / make.bat 中的部分。\n"
              "預設值為： makeindex。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "COMPACT_LATEX",
              "如果 COMPACT_LATEX 標籤設定為 YES ，Doxygen 會產生更紧凑的 LaTeX\n"
              "檔案。這對于小型專案可能很有用，通常可能有助于節省一些樹木。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "PAPER_TYPE",
              "PAPER_TYPE 標籤可用於設定列印机使用的纸张類別型。\n"
              "可能的值有：a4 （210 x 297 公釐）, letter （8.5 x 11 英吋）, legal （8.5 x 14 英吋）和executive\n"
              "（7.25 x 10.5 英吋）.\n"
              "預設值為： a4。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "EXTRA_PACKAGES",
              "EXTRA_PACKAGES 標籤可用於指定應包含在 LaTeX 輸出中的一個或多個 LaTeX 包名稱。可以僅通過名稱或使用與 LaTeX\n"
              "\\usepackage 命令一起使用的正確語法來指定包。例如，要取得 times 字型，您可以指定：\n"
              "EXTRA_PACKAGES=times 或 EXTRA_PACKAGES={times}\n"
              "要將選項 intlimits 與 amsmath 包一起使用，您可以指定：\n"
              "EXTRA_PACKAGES=[intlimits]{amsmath}\n"
              "如果留空，則不包含额外的包。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_HEADER",
              "LATEX_HEADER 標籤可用於為產生的 LaTeX 檔案指定使用者定義的 LaTeX\n"
              "頭檔案。頭檔案應包含直到第一章的所有內容。如果留空，Doxygen 將產生標准頭檔案。强烈建议使用預設頭檔案開始：\n"
              "doxygen -w latex new_header.tex new_footer.tex new_stylesheet.sty\n"
              "然後修改檔案 new_header.tex 。另請參閱第 \"Doxygen usage\" 節以取得有關如何產生 Doxygen\n"
              "通常使用的預設頭檔案的資訊。\n"
              "\n"
              "注意：只有在您知道自己在做什么時才使用使用者定義的頭檔案！\n"
              "注意： 頭檔案可能會更改，因此通常在升級到更新版本的 Doxygen 時必须重新產生預設頭檔案。有關可用標記和程式碼區塊名稱的說明，請參閱文件。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_FOOTER",
              "LATEX_FOOTER 標籤可用於為產生的 LaTeX 檔案指定使用者定義的 LaTeX\n"
              "頁脚。頁脚應包含最後一章之後的所有內容。如果留空，Doxygen 將產生標准頁脚。請參閱 LATEX_HEADER\n"
              "以取得有關如何產生預設頁脚以及頁脚內可以使用哪些特殊命令的更多資訊。另請參閱第 \"Doxygen usage\" 節以取得有關如何產生 Doxygen\n"
              "通常使用的預設頁脚的資訊。注意：只有在您知道自己在做什么時才使用使用者定義的頁脚！\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_EXTRA_STYLESHEET",
              "LATEX_EXTRA_STYLESHEET 標籤可用於指定在 Doxygen 建立的標准樣式資料表之後包含的其他使用者定義的 LaTeX\n"
              "樣式資料表。使用此選項可以覆寫某些樣式方面。Doxygen 會將樣式資料表檔案複製到輸出目錄。\n"
              "注意： 额外樣式資料表檔案的顺序很重要（例如，列資料表中的最後一個樣式資料表覆寫列資料表中前一個樣式資料表的設定）。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_EXTRA_FILES",
              "LATEX_EXTRA_FILES 標籤可用於指定一個或多個應複製到 LATEX_OUTPUT\n"
              "輸出目錄的额外影像或其他原始碼檔案。請注意，檔案將按原樣複製；沒有可用的命令或標記。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "PDF_HYPERLINKS",
              "如果 PDF_HYPERLINKS 標籤設定為 YES ，產生的 LaTeX 將准备轉換為 PDF（使用 ps2pdf 或 pdflatex ）。PDF\n"
              "檔案將包含連結（就像 HTML 輸出一樣）而不是頁面引用。這使得輸出适合使用 PDF 查看器進行在線浏览。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "USE_PDFLATEX",
              "如果 USE_PDFLATEX 標籤設定為 YES ，Doxygen 將使用 LATEX_CMD_NAME 指定的引擎直接從 LaTeX 檔案產生 PDF\n"
              "檔案。將此選項設定為 YES 以獲得更高品質的 PDF 檔案。\n"
              "\n"
              "另請參閱第 LATEX_CMD_NAME 節以選择引擎。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_BATCHMODE",
              "LATEX_BATCHMODE 標籤指示 LaTeX 在出現錯誤時的行為。\n"
              "可能的值有：NO 與ERROR_STOP相同, YES 與BATCH相同, BATCH 在批次模式下，終端不列印任何內容，錯誤會像在每個錯誤處按下<retu\n"
              "rn>一樣捲動；TeX嘗試輸入或從鍵盤輸入請求的缺失檔案（在未開啟的輸入串流上的\\read）會導致作業中止, NON_STOP\n"
              "在非停止模式下，診斷訊息將顯示在終端上，但像批次模式一樣無法進行使用者互動, SCROLL\n"
              "在捲動模式下，TeX僅在缺少輸入檔案或需要鍵盤輸入時停止和ERROR_STOP 在錯誤停止模式下，TeX在每個錯誤處停止，請求使用者干預.\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_HIDE_INDICES",
              "如果 LATEX_HIDE_INDICES 標籤設定為 YES ，Doxygen 將不在輸出中包含索引章節（如檔案索引、複合索引等）。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_BIB_STYLE",
              "LATEX_BIB_STYLE 標籤可用於指定參考文献使用的樣式，例如 plainnat 或 ieeetr 。請參閱\n"
              "https://en.wikipedia.org/wiki/BibTeX 和 \\cite 以取得更多資訊。\n"
              "預設值為： plainnat。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "LATEX_EMOJI_DIRECTORY",
              "LATEX_EMOJI_DIRECTORY 標籤用於指定讀取 emoji 影像的（相對或絕對）路徑。如果輸入相對路徑，它將相對于 LATEX_OUTPUT\n"
              "目錄。如果留空，則使用 LATEX_OUTPUT 目錄。\n"
              "此標籤要求標籤 GENERATE_LATEX 設定為YES。"
          );
  doc->add(
              "GENERATE_RTF",
              "如果 GENERATE_RTF 標籤設定為 YES ，Doxygen 將產生 RTF 輸出。RTF 輸出针對 Word 97 進行了最佳化，在其他 RTF\n"
              "閱讀器/編辑器中可能看起來不太漂亮。\n"
              "預設值為： NO。"
          );
  doc->add(
              "RTF_OUTPUT",
              "RTF_OUTPUT 標籤用於指定 RTF 檔案的放置位置。如果輸入相對路徑，則 OUTPUT_DIRECTORY 的值將放在其前面。\n"
              "預設目錄為：rtf。\n"
              "此標籤要求標籤 GENERATE_RTF 設定為YES。"
          );
  doc->add(
              "COMPACT_RTF",
              "如果 COMPACT_RTF 標籤設定為 YES ，Doxygen 會產生更紧凑的 RTF 檔案。這對于小型專案可能很有用，通常可能有助于節省一些樹木。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_RTF 設定為YES。"
          );
  doc->add(
              "RTF_HYPERLINKS",
              "如果 RTF_HYPERLINKS 標籤設定為 YES ，產生的 RTF 將包含超連結欄位。RTF 檔案將包含連結（就像 HTML\n"
              "輸出一樣）而不是頁面引用。這使得輸出适合使用 Word 或其他支援這些欄位的 Word 兼容閱讀器進行在線浏览。\n"
              "\n"
              "注意：寫字板（write）和其他程式不支援連結。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_RTF 設定為YES。"
          );
  doc->add(
              "RTF_STYLESHEET_FILE",
              "從檔案加載樣式資料表定義。語法類別似于 Doxygen 的設定檔案，即一系列赋值。您只需要提供取代，缺少的定義設定為其預設值。\n"
              "\n"
              "另請參閱第 \"Doxygen usage\" 節以取得有關如何產生 Doxygen 通常使用的預設樣式資料表的資訊。\n"
              "此標籤要求標籤 GENERATE_RTF 設定為YES。"
          );
  doc->add(
              "RTF_EXTENSIONS_FILE",
              "設定產生 RTF 檔案時使用的可選變數。語法類別似于 Doxygen 的設定檔案。可以使用 doxygen -e rtf extensionFile\n"
              "產生範本擴充功能檔案。\n"
              "此標籤要求標籤 GENERATE_RTF 設定為YES。"
          );
  doc->add(
              "RTF_EXTRA_FILES",
              "RTF_EXTRA_FILES 標籤可用於指定一個或多個應複製到 RTF_OUTPUT\n"
              "輸出目錄的额外影像或其他原始碼檔案。請注意，檔案將按原樣複製；沒有可用的命令或標記。\n"
              "此標籤要求標籤 GENERATE_RTF 設定為YES。"
          );
  doc->add(
              "GENERATE_MAN",
              "如果 GENERATE_MAN 標籤設定為 YES ，Doxygen 將為類別和檔案產生 man 頁面。\n"
              "預設值為： NO。"
          );
  doc->add(
              "MAN_OUTPUT",
              "MAN_OUTPUT 標籤用於指定 man 頁面的放置位置。如果輸入相對路徑，則 OUTPUT_DIRECTORY 的值將放在其前面。將在\n"
              "MAN_OUTPUT 指定的目錄內建立一個 man3 目錄。\n"
              "預設目錄為：man。\n"
              "此標籤要求標籤 GENERATE_MAN 設定為YES。"
          );
  doc->add(
              "MAN_EXTENSION",
              "MAN_EXTENSION 標籤确定添加到產生的 man 頁面的擴充功能名。如果手册部分不以數字開頭，則在前面加上數字 3。 MAN_EXTENSION\n"
              "標籤開頭的點（.）是可選的。\n"
              "預設值為： .3。\n"
              "此標籤要求標籤 GENERATE_MAN 設定為YES。"
          );
  doc->add(
              "MAN_SUBDIR",
              "MAN_SUBDIR 標籤确定在 MAN_OUTPUT 中建立的放置 man 頁面的目錄名稱。預設為 man 後跟 MAN_EXTENSION\n"
              "，並移除初始 .。\n"
              "此標籤要求標籤 GENERATE_MAN 設定為YES。"
          );
  doc->add(
              "MAN_LINKS",
              "如果 MAN_LINKS 標籤設定為 YES 且 Doxygen 產生 man 輸出，則它將為真實 man 頁面中記錄的每個實體產生一個额外的 man\n"
              "檔案。這些额外的檔案僅引用真實的 man 頁面，但沒有它們， man 命令將無法找到正確的頁面。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_MAN 設定為YES。"
          );
  doc->add(
              "GENERATE_XML",
              "如果 GENERATE_XML 標籤設定為 YES ，Doxygen 將產生一個捕獲程式碼結構（包括所有檔案）的 XML 檔案。\n"
              "預設值為： NO。"
          );
  doc->add(
              "XML_OUTPUT",
              "XML_OUTPUT 標籤用於指定 XML 頁面的放置位置。如果輸入相對路徑，則 OUTPUT_DIRECTORY 的值將放在其前面。\n"
              "預設目錄為：xml。\n"
              "此標籤要求標籤 GENERATE_XML 設定為YES。"
          );
  doc->add(
              "XML_PROGRAMLISTING",
              "如果 XML_PROGRAMLISTING 標籤設定為 YES ，Doxygen 將把程式列資料表（包括語法高亮和交叉引用資訊）轉储到 XML\n"
              "輸出。請注意，啟用此功能將顯著增加 XML 輸出的大小。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_XML 設定為YES。"
          );
  doc->add(
              "XML_NS_MEMB_FILE_SCOPE",
              "如果 XML_NS_MEMB_FILE_SCOPE 標籤設定為 YES ，Doxygen 也會在檔案作用域中包含命名空間成員，與 HTML 輸出匹配。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_XML 設定為YES。"
          );
  doc->add(
              "GENERATE_DOCBOOK",
              "如果 GENERATE_DOCBOOK 標籤設定為 YES ，Doxygen 將產生可用於產生 PDF 的 Docbook 檔案。\n"
              "預設值為： NO。"
          );
  doc->add(
              "DOCBOOK_OUTPUT",
              "DOCBOOK_OUTPUT 標籤用於指定 Docbook 頁面的放置位置。如果輸入相對路徑，則 OUTPUT_DIRECTORY 的值將放在其前面。\n"
              "預設目錄為：docbook。\n"
              "此標籤要求標籤 GENERATE_DOCBOOK 設定為YES。"
          );
  doc->add(
              "GENERATE_AUTOGEN_DEF",
              "如果 GENERATE_AUTOGEN_DEF 標籤設定為 YES ，Doxygen 將產生一個捕獲程式碼結構（包括所有檔案）的 AutoGen\n"
              "定義（請參閱 https://autogen.sourceforge.net/）檔案。請注意，此功能目前仍處于實驗阶段且不完整。\n"
              "預設值為： NO。"
          );
  doc->add(
              "GENERATE_SQLITE3",
              "如果 GENERATE_SQLITE3 標籤設定為 YES ，Doxygen 將產生一個 Sqlite3 資料库，其中包含 Doxygen\n"
              "找到的符號存儲在資料表中。\n"
              "預設值為： NO。"
          );
  doc->add(
              "SQLITE3_OUTPUT",
              "SQLITE3_OUTPUT 標籤用於指定 Sqlite3 資料库的放置位置。如果輸入相對路徑，則 OUTPUT_DIRECTORY 的值將放在其前面。\n"
              "預設目錄為：sqlite3。\n"
              "此標籤要求標籤 GENERATE_SQLITE3 設定為YES。"
          );
  doc->add(
              "SQLITE3_RECREATE_DB",
              "如果 SQLITE3_RECREATE_DB 標籤設定為 YES ，每次 Doxygen 運行時都會重新建立現有的 doxygen_sqlite3.db\n"
              "資料库檔案。如果設定為 NO ，如果已经找到資料库檔案，Doxygen 將發出警告並且不會修改它。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_SQLITE3 設定為YES。"
          );
  doc->add(
              "GENERATE_PERLMOD",
              "如果 GENERATE_PERLMOD 標籤設定為 YES ，Doxygen 將產生一個捕獲程式碼結構（包括所有檔案）的 Perl 模組檔案。\n"
              "\n"
              "請注意，此功能目前仍處于實驗阶段且不完整。\n"
              "預設值為： NO。"
          );
  doc->add(
              "PERLMOD_LATEX",
              "如果 PERLMOD_LATEX 標籤設定為 YES ，Doxygen 將產生必要的 Makefile 規則、 Perl 脚本和 LaTeX\n"
              "程式碼，以便能够從 Perl 模組輸出產生 PDF 和 DVI 輸出。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 GENERATE_PERLMOD 設定為YES。"
          );
  doc->add(
              "PERLMOD_PRETTY",
              "如果 PERLMOD_PRETTY 標籤設定為 YES ，Perl\n"
              "模組輸出將被很好地格式化，以便人類別閱讀器解析。如果您想了解發生了什么，這很有用。另一方面，如果此標籤設定為 NO ，Perl\n"
              "模組輸出的大小將小得多，Perl 也會同樣解析它。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 GENERATE_PERLMOD 設定為YES。"
          );
  doc->add(
              "PERLMOD_MAKEVAR_PREFIX",
              "產生的 doxyrules.make 檔案中的 make 變數名稱以 PERLMOD_MAKEVAR_PREFIX 中包含的字元串為前缀。這很有用，因此同一\n"
              "Makefile 包含的不同 doxyrules.make 檔案不會相互覆寫變數。\n"
              "此標籤要求標籤 GENERATE_PERLMOD 設定為YES。"
          );
  doc->add(
              "ENABLE_PREPROCESSING",
              "如果 ENABLE_PREPROCESSING 標籤設定為 YES ，Doxygen 將评估原始碼檔案和包含檔案中找到的所有 C 前置處理指令。\n"
              "預設值為： YES。"
          );
  doc->add(
              "MACRO_EXPANSION",
              "如果 MACRO_EXPANSION 標籤設定為 YES ，Doxygen 將展開原始碼程式碼中的所有巨集名稱。如果設定為 NO\n"
              "，則只執行条件編译。可以通過將 EXPAND_ONLY_PREDEF 設定為 YES 以受控方式完成巨集展開。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 ENABLE_PREPROCESSING 設定為YES。"
          );
  doc->add(
              "EXPAND_ONLY_PREDEF",
              "如果 EXPAND_ONLY_PREDEF 和 MACRO_EXPANSION 標籤都設定為 YES ，則巨集展開僅限于使用 PREDEFINED 和\n"
              "EXPAND_AS_DEFINED 標籤指定的巨集。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 ENABLE_PREPROCESSING 設定為YES。"
          );
  doc->add(
              "SEARCH_INCLUDES",
              "如果 SEARCH_INCLUDES 標籤設定為 YES ，如果找到 #include ，則搜尋 INCLUDE_PATH 中的包含檔案。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 ENABLE_PREPROCESSING 設定為YES。"
          );
  doc->add(
              "INCLUDE_PATH",
              "INCLUDE_PATH 標籤可用於指定一個或多個包含不是輸入檔案但應由前置處理器處理的包含檔案的目錄。請注意， INCLUDE_PATH\n"
              "不是遞迴的，因此 RECURSIVE 的設定在此无效。\n"
              "此標籤要求標籤 SEARCH_INCLUDES 設定為YES。"
          );
  doc->add(
              "INCLUDE_FILE_PATTERNS",
              "您可以使用 INCLUDE_FILE_PATTERNS 標籤指定一個或多個通配符模式（如 *.h 和 *.hpp）來過濾目錄中的頭檔案。如果留空，則使用\n"
              "FILE_PATTERNS 指定的模式。\n"
              "此標籤要求標籤 ENABLE_PREPROCESSING 設定為YES。"
          );
  doc->add(
              "PREDEFINED",
              "PREDEFINED 標籤可用於指定在前置處理器啟動之前定義的一個或多個巨集名稱（類別似于例如 gcc 的 -D\n"
              "選項）。標籤的參數是以下形式的巨集列資料表：name 或 name=definition（无空格）。如果省略定義和 \"=\" ，則假設為 \"=1\"\n"
              "。要防止巨集定義通過 #undef 取消定義或遞迴展開，請使用 := 運算子而不是 = 運算子。\n"
              "此標籤要求標籤 ENABLE_PREPROCESSING 設定為YES。"
          );
  doc->add(
              "EXPAND_AS_DEFINED",
              "如果 MACRO_EXPANSION 和 EXPAND_ONLY_PREDEF 標籤設定為 YES\n"
              "，則此標籤可用於指定應展開的巨集名稱列資料表。將使用在原始碼程式碼中找到的巨集定義。如果您想使用覆寫原始碼程式碼中找到的定義的不同巨集定義，請使用\n"
              "PREDEFINED 標籤。\n"
              "此標籤要求標籤 ENABLE_PREPROCESSING 設定為YES。"
          );
  doc->add(
              "SKIP_FUNCTION_MACROS",
              "如果 SKIP_FUNCTION_MACROS 標籤設定為 YES ，Doxygen\n"
              "的前置處理器將刪除所有對單独一行、具有全大寫名稱且不以分號結尾的類別函式巨集的引用。此類別函式巨集通常用於樣板程式碼，如果不刪除，會使解析器混淆。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 ENABLE_PREPROCESSING 設定為YES。"
          );
  doc->add(
              "TAGFILES",
              "TAGFILES 標籤可用於指定一個或多個標籤檔案。對于每個標籤檔案，應添加外部檔案的位置。沒有此位置的標籤檔案的格式如下：\n"
              "TAGFILES = file1 file2 ...\n"
              "為標籤檔案添加位置的方式如下：\n"
              "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
              "其中 loc1 和 loc2 可以是相對或絕對路徑或 URL。有關使用標籤檔案的更多資訊，請參閱第 \"Linking to external\n"
              "documentation\" 節。\n"
              "注意： 每個標籤檔案必须具有唯一的名稱（其中名稱不包括路徑）。如果標籤檔案不在運行 Doxygen 的目錄中，您还必须在此處指定標籤檔案的路徑。"
          );
  doc->add(
              "GENERATE_TAGFILE",
              "在 GENERATE_TAGFILE 後指定檔案名時，Doxygen 將建立一個基於其讀取的輸入檔案的標籤檔案。有關標籤檔案使用的更多資訊，請參閱第\n"
              "\"Linking to external documentation\" 節。"
          );
  doc->add(
              "ALLEXTERNALS",
              "如果 ALLEXTERNALS 標籤設定為 YES ，所有外部類別和命名空間都將列在類別和命名空間索引中。如果設定為 NO ，則只列出繼承的外部類別。\n"
              "預設值為： NO。"
          );
  doc->add(
              "EXTERNAL_GROUPS",
              "如果 EXTERNAL_GROUPS 標籤設定為 YES ，所有外部群組都將列在主题索引中。如果設定為 NO ，則只列出目前專案的群組。\n"
              "預設值為： YES。"
          );
  doc->add(
              "EXTERNAL_PAGES",
              "如果 EXTERNAL_PAGES 標籤設定為 YES ，所有外部頁面都將列在相關頁面索引中。如果設定為 NO ，則只列出目前專案的頁面。\n"
              "預設值為： YES。"
          );
  doc->add(
              "HIDE_UNDOC_RELATIONS",
              "如果設定為 YES ，繼承和協作圖將隐藏目標未記錄或不是類別的繼承和使用關系。\n"
              "預設值為： YES。"
          );
  doc->add(
              "HAVE_DOT",
              "如果將 HAVE_DOT 標籤設定為 YES ，Doxygen 將假設 dot 工具可從 path 獲得。此工具是 Graphviz (see:\n"
              "https://www.graphviz.org/) 的一部分，這是 AT&T 和 Lucent Bell Labs 的圖形可视化工具包。如果此選項設定為\n"
              "NO ，本節中的其他選項无效\n"
              "預設值為： NO。"
          );
  doc->add(
              "DOT_NUM_THREADS",
              "DOT_NUM_THREADS 指定 Doxygen 允許平行運行的 dot 呼叫次數。設定為 0 時，Doxygen\n"
              "將根據系統中可用的處理器數量進行設定。您可以將其顯式設定為大于 0 的值，以更好地控制 CPU 負載和處理速度之間的平衡。\n"
              "最小值：0，最大值：512，預設值：0。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOT_BATCH_SIZE",
              "DOT_BATCH_SIZE 指定 Doxygen 在單次 dot 呼叫中允許編譯的 dot 圖表數量。 當設定為 1 時，Doxygen\n"
              "將為每個圖表單獨呼叫 dot ，這可能會導致顯著的進程建立開銷， 特別是在具有許多 CPU 核心的系統上。與 DOT_NUM_THREADS\n"
              "一起使用此設定可以最佳化特定系統的 dot 處理速度。Doxygen 將嘗試為每個執行緒分配均衡的工作量。如果要處理的圖表總數超過\n"
              "DOT_NUM_THREADS * DOT_BATCH_SIZE，則會為 dot 建立額外的批次進行處理。\n"
              "最小值：1，最大值：1000，預設值：50。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOT_COMMON_ATTR",
              "DOT_COMMON_ATTR 是子圖的節點、邊緣和標籤的公共屬性。當您希望 Doxygen 產生的 dot 檔案中的字型外观不同時，可以指定\n"
              "fontname、fontcolor 和 fontsize 屬性。有關詳細資訊，請參閱 <a\n"
              "href=https://graphviz.org/doc/info/attrs.html>節點、邊緣和圖屬性規范</a> 您需要确保 dot\n"
              "能够找到字型，這可以通過將其放在標准位置或設定 DOTFONTPATH 环境變數或將 DOT_FONTPATH 設定為包含字型的目錄來完成。預設\n"
              "graphviz 字型大小為 14。\n"
              "預設值為： fontname=Helvetica,fontsize=10。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOT_EDGE_ATTR",
              "DOT_EDGE_ATTR 與 DOT_COMMON_ATTR 連線。對于优雅的樣式，您可以添加 'arrowhead=open,\n"
              "arrowtail=open, arrowsize=0.5'。<a\n"
              "href=https://graphviz.org/doc/info/arrows.html>有關箭頭形状的完整檔案。</a>\n"
              "預設值為： labelfontname=Helvetica,labelfontsize=10。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOT_NODE_ATTR",
              "DOT_NODE_ATTR 與 DOT_COMMON_ATTR 連線。對于沒有節點周围框的视圖，設定 'shape=plain' 或\n"
              "'shape=plaintext' <a\n"
              "href=https://www.graphviz.org/doc/info/shapes.html>形状規范</a>\n"
              "預設值為： shape=box,height=0.2,width=0.4。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOT_FONTPATH",
              "您可以設定 dot 可以找到在 DOT_COMMON_ATTR 和其他 dot 屬性中使用 fontname 指定的字型的路徑。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "CLASS_GRAPH",
              "如果 CLASS_GRAPH 標籤設定為 YES 或 GRAPH 或 BUILTIN ，Doxygen\n"
              "將為每個已記錄的類別產生一個圖，顯示直接和間接繼承關系。如果 CLASS_GRAPH 標籤設定為 YES 或 GRAPH 且啟用了\n"
              "HAVE_DOT，則將使用 dot 绘制圖。如果 CLASS_GRAPH 標籤設定為 YES 且停用了 HAVE_DOT，或者如果 CLASS_GRAPH\n"
              "標籤設定為 BUILTIN ，則將使用內建產生器。如果 CLASS_GRAPH 標籤設定為 TEXT ，直接和間接繼承關系將顯示為文本/連結。可以通過命令\n"
              "\\inheritancegraph 為特定類別顯式啟用繼承圖或選择不同的資料表示形式。可以通過命令 \\hideinheritancegraph 停用繼承圖。\n"
              "可能的值有：NO, YES, TEXT, GRAPH和BUILTIN.\n"
              "預設值為： YES。"
          );
  doc->add(
              "COLLABORATION_GRAPH",
              "如果 COLLABORATION_GRAPH 標籤設定為 YES ，Doxygen\n"
              "將為每個已記錄的類別產生一個圖，顯示該類別與其他已記錄類別之間的直接和間接實現相依性關系（繼承、包含和類別引用變數）。當\n"
              "COLLABORATION_GRAPH 設定為 NO 時，可以通過命令 \\collaborationgraph 顯式啟用協作圖。可以通過命令\n"
              "\\hidecollaborationgraph 停用協作圖。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "GROUP_GRAPHS",
              "如果 GROUP_GRAPHS 標籤設定為 YES ，Doxygen 將為群組產生圖，顯示直接的群組相依性關系。當 GROUP_GRAPHS 設定為 NO\n"
              "時，可以通過命令 \\groupgraph 顯式啟用群組相依性圖。可以通過命令 \\hidegroupgraph 停用目錄圖。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "UML_LOOK",
              "如果 UML_LOOK 標籤設定為 YES ，Doxygen 將以類別似于 OMG 统一建模語言的风格產生繼承和協作圖。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "UML_LIMIT_NUM_FIELDS",
              "如果啟用了 UML_LOOK 標籤，欄位和方法將顯示在類別節點內。如果有很多欄位或方法和很多節點，圖可能變得太大而無法使用。\n"
              "UML_LIMIT_NUM_FIELDS 阈值限制每种類別型的項數，以使大小更易于管理。將此設定為 0\n"
              "資料表示无限制。請注意，在强制執行限制之前，阈值可能會超出 50%。因此，當您將阈值設定為 10 時，最多可能出現 15 個欄位，但如果數量超過\n"
              "15，則顯示的欄位总數限制為 10。\n"
              "最小值：0，最大值：100，預設值：10。\n"
              "此標籤要求標籤 UML_LOOK 設定為YES。"
          );
  doc->add(
              "UML_MAX_EDGE_LABELS",
              "如果啟用了 UML_LOOK 標籤，欄位標籤將沿着兩個類別節點之間的邊緣顯示。如果有很多欄位和很多節點，圖可能變得太杂乱。\n"
              "UML_MAX_EDGE_LABELS 阈值限制項數，以使大小更易于管理。將此設定為 0 資料表示无限制。\n"
              "最小值：0，最大值：100，預設值：10。\n"
              "此標籤要求標籤 UML_LOOK 設定為YES。"
          );
  doc->add(
              "DOT_UML_DETAILS",
              "如果 DOT_UML_DETAILS 標籤設定為 NO ，Doxygen 將在 UML 圖中顯示不带類別型和參數的屬性和方法。如果\n"
              "DOT_UML_DETAILS 標籤設定為 YES ，Doxygen 將在 UML 圖中為屬性和方法添加類別型和參數。如果 DOT_UML_DETAILS\n"
              "標籤設定為 NONE，Doxygen 將不在 UML 圖中產生包含類別成員資訊的欄位。類別圖看起來類別似于預設類別圖，但使用 UML\n"
              "資料表示法資料表示關系。\n"
              "可能的值有：NO, YES和NONE.\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 UML_LOOK 設定為YES。"
          );
  doc->add(
              "DOT_WRAP_THRESHOLD",
              "DOT_WRAP_THRESHOLD\n"
              "標籤可用於設定在單行上顯示的最大字元數。如果實際行長度顯著超過此阈值，它將被換行到多行。應用了一些啟發式方法以避免难看的換行。\n"
              "最小值：0，最大值：1000，預設值：17。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "TEMPLATE_RELATIONS",
              "如果 TEMPLATE_RELATIONS 標籤設定為 YES ，繼承和協作圖將顯示範本與其實例之間的關系。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "INCLUDE_GRAPH",
              "如果 INCLUDE_GRAPH 、ENABLE_PREPROCESSING 和 SEARCH_INCLUDES 標籤設定為 YES ，Doxygen\n"
              "將為每個已記錄的檔案產生一個圖，顯示該檔案與其他已記錄檔案之間的直接和間接包含相依性關系。當 INCLUDE_GRAPH 設定為 NO 時，可以通過命令\n"
              "\\includegraph 顯式啟用包含圖。可以通過命令 \\hideincludegraph 停用包含圖。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "INCLUDED_BY_GRAPH",
              "如果 INCLUDED_BY_GRAPH 、ENABLE_PREPROCESSING 和 SEARCH_INCLUDES 標籤設定為 YES\n"
              "，Doxygen 將為每個已記錄的檔案產生一個圖，顯示該檔案與其他已記錄檔案之間的直接和間接包含相依性關系。當 INCLUDED_BY_GRAPH 設定為\n"
              "NO 時，可以通過命令 \\includedbygraph 顯式啟用被包含圖。可以通過命令 \\hideincludedbygraph 停用被包含圖。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "CALL_GRAPH",
              "如果 CALL_GRAPH 標籤設定為 YES ，Doxygen 將為每個全局函式或類別方法產生呼叫相依性圖。\n"
              "\n"
              "請注意，啟用此選項將顯著增加運行時間。因此在大多數情况下，最好只使用 \\callgraph 命令為選定的函式啟用呼叫圖。可以通過\n"
              "\\hidecallgraph 命令停用呼叫圖。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "CALLER_GRAPH",
              "如果 CALLER_GRAPH 標籤設定為 YES ，Doxygen 將為每個全局函式或類別方法產生呼叫者相依性圖。\n"
              "\n"
              "請注意，啟用此選項將顯著增加運行時間。因此在大多數情况下，最好只使用 \\callergraph 命令為選定的函式啟用呼叫者圖。可以通過\n"
              "\\hidecallergraph 命令停用呼叫者圖。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "GRAPHICAL_HIERARCHY",
              "如果 GRAPHICAL_HIERARCHY 標籤設定為 YES ，Doxygen 將以圖形方式顯示所有類別的層次結構，而不是文本形式。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DIRECTORY_GRAPH",
              "如果 DIRECTORY_GRAPH 標籤設定為 YES ，Doxygen 將以圖形方式顯示目錄對其他目錄的相依性關系。相依性關系由目錄中檔案之間的\n"
              "#include 關系确定。當 DIRECTORY_GRAPH 設定為 NO 時，可以通過命令 \\directorygraph 顯式啟用目錄圖。可以通過命令\n"
              "\\hidedirectorygraph 停用目錄圖。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DIR_GRAPH_MAX_DEPTH",
              "DIR_GRAPH_MAX_DEPTH 標籤可用於限制由 dot 在目錄相依性圖中產生的子目錄層級的最大數量。\n"
              "最小值：1，最大值：25，預設值：1。\n"
              "此標籤要求標籤 DIRECTORY_GRAPH 設定為YES。"
          );
  doc->add(
              "DOT_IMAGE_FORMAT",
              "DOT_IMAGE_FORMAT 標籤可用於設定由 dot 產生的影像的影像格式。有關影像格式的說明，請參閱 dot\n"
              "工具檔案中的輸出格式部分（Graphviz (see:\n"
              "https://www.graphviz.org/)）。\n"
              "\n"
              "請注意，格式 svg:cairo 和 svg:cairo:cairo 不能與 INTERACTIVE_SVG 結合使用（INTERACTIVE_SVG\n"
              "將設定為 NO）。\n"
              "可能的值有：png, jpg, gif, svg, png:gd, png:gd:gd, png:cairo, png:cairo:gd,\n"
              "png:cairo:cairo, png:cairo:gdiplus, png:gdiplus, png:gdiplus:gdiplus,\n"
              "svg:cairo, svg:cairo:cairo, svg:svg, svg:svg:core, gif:cairo, gif:cairo:gd,\n"
              "gif:cairo:gdiplus, gif:gdiplus, gif:gdiplus:gdiplus, gif:gd, gif:gd:gd,\n"
              "jpg:cairo, jpg:cairo:gd, jpg:cairo:gdiplus, jpg:gd, jpg:gd:gd,\n"
              "jpg:gdiplus和jpg:gdiplus:gdiplus.\n"
              "預設值為： png。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "INTERACTIVE_SVG",
              "如果 DOT_IMAGE_FORMAT 設定為 svg 或 svg:svg 或 svg:svg:core，則可以將此選項設定為 YES\n"
              "以啟用允許縮放和平移的交互式 SVG 影像的產生。\n"
              "\n"
              "請注意，這需要除 Internet Explorer 之外的現代瀏覽器。已測試並正常工作的有 Firefox、Chrome、Safari 和 Opera。\n"
              "\n"
              "注意，當 DOT_IMAGE_FORMAT 設定為 svg:cairo 或 svg:cairo:cairo 時，此選項將自動停用。\n"
              "預設值為： NO。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOT_PATH",
              "DOT_PATH 標籤可用於指定可以找到 dot 工具的路徑。如果留空，則假設 dot 工具可以在 path 中找到。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOTFILE_DIRS",
              "DOTFILE_DIRS 標籤可用於指定一個或多個包含包含在檔案中的 dot 檔案的目錄（請參閱 \\dotfile 命令）。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DIA_PATH",
              "您可以在 Doxygen 檔案中包含使用 dia 制作的圖資料表。Doxygen 随後將運行 dia 產生圖資料表並將其插入檔案中。DIA_PATH\n"
              "標籤允許您指定 dia 二進制檔案所在的目錄。如果留空，則假設 dia 可以在預設搜尋路徑中找到。"
          );
  doc->add(
              "DIAFILE_DIRS",
              "DIAFILE_DIRS 標籤可用於指定一個或多個包含包含在檔案中的 dia 檔案的目錄（請參閱 \\diafile 命令）。"
          );
  doc->add(
              "PLANTUML_JAR_PATH",
              "使用 PlantUML 時， PLANTUML_JAR_PATH 標籤應用於指定 java 可以找到 plantuml.jar 檔案的路徑或要使用的 jar\n"
              "檔案的檔案名。如果留空，則假設不使用 PlantUML 或在前置處理步骤中呼叫。在這种情况下，Doxygen 在遇到 \\startuml\n"
              "命令時會產生警告，並且不會為圖資料表產生輸出。"
          );
  doc->add(
              "PLANTUML_CFG_FILE",
              "使用 PlantUML 時， PLANTUML_CFG_FILE 標籤可用於為 PlantUML 指定設定檔案。"
          );
  doc->add(
              "PLANTUML_INCLUDE_PATH",
              "使用 PlantUML 時，指定的路徑用於搜尋 PlantUML 塊中 !include 语句指定的檔案。"
          );
  doc->add(
              "PLANTUMLFILE_DIRS",
              "PLANTUMLFILE_DIRS 標籤可用於指定一個或多個包含包含在檔案中的 PlantUml 檔案的目錄（請參閱 \\plantumlfile 命令）。"
          );
  doc->add(
              "MERMAID_PATH",
              "使用带有 CLI 呈現的 Mermaid 圖資料表時， MERMAID_PATH 標籤應用於指定可以找到 mmdc (Mermaid CLI)\n"
              "可執行檔案的目錄。如果留空，則停用基於 CLI 的呈現。對于 HTML 輸出，預設通過 JavaScript 使用客戶端呈現，不需要 mmdc 。對于\n"
              "LaTeX/PDF 輸出，需要 mmdc 來預產生影像。當需要 CLI 呈現但 mmdc 不可用時，Doxygen 將產生警告。"
          );
  doc->add(
              "MERMAID_CONFIG_FILE",
              "使用 Mermaid 圖資料表時， MERMAID_CONFIG_FILE 標籤可用於為 Mermaid CLI 工具（ mmdc ）指定 JSON\n"
              "設定檔案。此檔案可以包含主题設定和其他 Mermaid 設定選項。"
          );
  doc->add(
              "MERMAID_RENDER_MODE",
              "MERMAID_RENDER_MODE 標籤選择如何呈現 Mermaid 圖資料表。\n"
              "可能的值有：AUTO （HTML使用客戶端渲染，LaTeX/PDF和其他格式使用 mmdc 。如果未設定 MERMAID_PATH\n"
              "，非HTML圖表將產生警告）, CLI （使用 mmdc 工具預產生影像（需要 Node.js 和mermaid-js/mermaid-\n"
              "cli）。適用於所有輸出格式）和CLIENT_SIDE （在HTML輸出中嵌入 mermaid.js 進行客戶端渲染。不需要 mmdc\n"
              "但僅適用於HTML輸出）.\n"
              "預設值為： AUTO。"
          );
  doc->add(
              "MERMAID_JS_URL",
              "MERMAID_JS_URL 標籤指定在使用客戶端呈現時（ MERMAID_RENDER_MODE 為 CLIENT_SIDE 或 AUTO ）從中加載\n"
              "mermaid.js 的 URL。預設指向 jsDelivr CDN 上最新的 Mermaid v11 版本。\n"
              "\n"
              "預設 CDN URL 在查看產生的檔案時需要互聯网访問。對于离線使用，請下載 mermaid.esm.min.mjs 並將其設定為相對路徑，或使用\n"
              "MERMAID_RENDER_MODE=CLI 代替預產生影像。\n"
              "示例：\n"
              "- 最新 v11（預設）：https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs\n"
              "- 固定版本：https://cdn.jsdelivr.net/npm/mermaid@11.3.0/dist/mermaid.esm.min.mjs\n"
              "- 本地副本：./mermaid.esm.min.mjs（使用者必须將檔案放在 HTML 輸出目錄中）\n"
              "預設值為： https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs。"
          );
  doc->add(
              "MERMAIDFILE_DIRS",
              "MERMAIDFILE_DIRS 標籤可用於指定一個或多個包含包含在檔案中的 Mermaid 檔案的目錄（請參閱 \\mermaidfile 命令）。"
          );
  doc->add(
              "DOT_GRAPH_MAX_NODES",
              "DOT_GRAPH_MAX_NODES 標籤可用於設定圖中顯示的最大節點數。如果圖中的節點數變得大于此值，Doxygen\n"
              "將截断圖，這通過將節點資料表示為红色框來可视化。請注意，如果圖中根節點的直接子節點數已经大于 DOT_GRAPH_MAX_NODES\n"
              "，則根本不會顯示圖。另請注意，圖的大小可以通過 MAX_DOT_GRAPH_DEPTH 進一步限制。\n"
              "最小值：0，最大值：10000，預設值：50。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "MAX_DOT_GRAPH_DEPTH",
              "MAX_DOT_GRAPH_DEPTH 標籤可用於設定由 dot 產生的圖的最大深度。深度值 3 意味着只顯示從根通過最多 3\n"
              "条邊緣的路徑可达的節點。距离根節點更远的節點將被省略。請注意，將此選項設定為 1 或 2\n"
              "可能會大大减少大型程式碼库所需的计算時間。另請注意，圖的大小可以通過 DOT_GRAPH_MAX_NODES 進一步限制。使用深度 0\n"
              "資料表示沒有深度限制。\n"
              "最小值：0，最大值：1000，預設值：0。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "GENERATE_LEGEND",
              "如果 GENERATE_LEGEND 標籤設定為 YES ，Doxygen 將產生一個圖例頁面，解释 dot 產生的圖中各种框和箭頭的含義。\n"
              "注意： 此標籤要求未設定 UML_LOOK，即使用 Doxygen 內部繼承和協作圖的圖形資料表示。\n"
              "預設值為： YES。\n"
              "此標籤要求標籤 HAVE_DOT 設定為YES。"
          );
  doc->add(
              "DOT_CLEANUP",
              "如果 DOT_CLEANUP 標籤設定為 YES ，Doxygen 將刪除用於產生各种圖的中間檔案。\n"
              "\n"
              "注意：此設定不僅用於 dot 檔案，还用於 msc 临時檔案。\n"
              "預設值為： YES。"
          );
  doc->add(
              "MSCGEN_TOOL",
              "您可以使用 \\msc 命令在 Doxygen 註解中定義訊息序列圖。如果 MSCGEN_TOOL 標籤留空（預設），則 Doxygen 將使用內建版本的\n"
              "mscgen 工具來產生圖資料表。或者， MSCGEN_TOOL 標籤也可以指定外部工具的名稱。例如，指定 prog 作為值，Doxygen 將呼叫工具為\n"
              "prog -T <outfile_format> -o <outputfile> <inputfile>。外部工具應支援輸出檔案格式\n"
              "\"png\"、\"eps\"、\"svg\" 和 \"ismap\"。"
          );
  doc->add(
              "MSCFILE_DIRS",
              "MSCFILE_DIRS 標籤可用於指定一個或多個包含包含在檔案中的 msc 檔案的目錄（請參閱 \\mscfile 命令）。"
          );
}
